declare const _default: {
    /**
     * Lookup3: frame_system::AccountInfo<Index, pallet_balances::AccountData<Balance>>
     */
    FrameSystemAccountInfo: {
        nonce: string;
        consumers: string;
        providers: string;
        sufficients: string;
        data: string;
    };
    /**
     * Lookup5: pallet_balances::AccountData<Balance>
     */
    PalletBalancesAccountData: {
        free: string;
        reserved: string;
        miscFrozen: string;
        feeFrozen: string;
    };
    /**
     * Lookup7: frame_support::dispatch::PerDispatchClass<sp_weights::weight_v2::Weight>
     */
    FrameSupportDispatchPerDispatchClassWeight: {
        normal: string;
        operational: string;
        mandatory: string;
    };
    /**
     * Lookup8: sp_weights::weight_v2::Weight
     */
    SpWeightsWeightV2Weight: {
        refTime: string;
        proofSize: string;
    };
    /**
     * Lookup14: sp_runtime::generic::digest::Digest
     */
    SpRuntimeDigest: {
        logs: string;
    };
    /**
     * Lookup16: sp_runtime::generic::digest::DigestItem
     */
    SpRuntimeDigestDigestItem: {
        _enum: {
            Other: string;
            __Unused1: string;
            __Unused2: string;
            __Unused3: string;
            Consensus: string;
            Seal: string;
            PreRuntime: string;
            __Unused7: string;
            RuntimeEnvironmentUpdated: string;
        };
    };
    /**
     * Lookup19: frame_system::EventRecord<moonbase_runtime::RuntimeEvent,
     * primitive_types::H256>
     */
    FrameSystemEventRecord: {
        phase: string;
        event: string;
        topics: string;
    };
    /**
     * Lookup21: frame_system::pallet::Event<T>
     */
    FrameSystemEvent: {
        _enum: {
            ExtrinsicSuccess: {
                dispatchInfo: string;
            };
            ExtrinsicFailed: {
                dispatchError: string;
                dispatchInfo: string;
            };
            CodeUpdated: string;
            NewAccount: {
                account: string;
            };
            KilledAccount: {
                account: string;
            };
            Remarked: {
                _alias: {
                    hash_: string;
                };
                sender: string;
                hash_: string;
            };
        };
    };
    /**
     * Lookup22: frame_support::dispatch::DispatchInfo
     */
    FrameSupportDispatchDispatchInfo: {
        weight: string;
        class: string;
        paysFee: string;
    };
    /**
     * Lookup23: frame_support::dispatch::DispatchClass
     */
    FrameSupportDispatchDispatchClass: {
        _enum: string[];
    };
    /**
     * Lookup24: frame_support::dispatch::Pays
     */
    FrameSupportDispatchPays: {
        _enum: string[];
    };
    /**
     * Lookup25: sp_runtime::DispatchError
     */
    SpRuntimeDispatchError: {
        _enum: {
            Other: string;
            CannotLookup: string;
            BadOrigin: string;
            Module: string;
            ConsumerRemaining: string;
            NoProviders: string;
            TooManyConsumers: string;
            Token: string;
            Arithmetic: string;
            Transactional: string;
            Exhausted: string;
            Corruption: string;
            Unavailable: string;
        };
    };
    /**
     * Lookup26: sp_runtime::ModuleError
     */
    SpRuntimeModuleError: {
        index: string;
        error: string;
    };
    /**
     * Lookup27: sp_runtime::TokenError
     */
    SpRuntimeTokenError: {
        _enum: string[];
    };
    /**
     * Lookup28: sp_runtime::ArithmeticError
     */
    SpRuntimeArithmeticError: {
        _enum: string[];
    };
    /**
     * Lookup29: sp_runtime::TransactionalError
     */
    SpRuntimeTransactionalError: {
        _enum: string[];
    };
    /**
     * Lookup30: pallet_utility::pallet::Event
     */
    PalletUtilityEvent: {
        _enum: {
            BatchInterrupted: {
                index: string;
                error: string;
            };
            BatchCompleted: string;
            BatchCompletedWithErrors: string;
            ItemCompleted: string;
            ItemFailed: {
                error: string;
            };
            DispatchedAs: {
                result: string;
            };
        };
    };
    /**
     * Lookup33: pallet_balances::pallet::Event<T, I>
     */
    PalletBalancesEvent: {
        _enum: {
            Endowed: {
                account: string;
                freeBalance: string;
            };
            DustLost: {
                account: string;
                amount: string;
            };
            Transfer: {
                from: string;
                to: string;
                amount: string;
            };
            BalanceSet: {
                who: string;
                free: string;
                reserved: string;
            };
            Reserved: {
                who: string;
                amount: string;
            };
            Unreserved: {
                who: string;
                amount: string;
            };
            ReserveRepatriated: {
                from: string;
                to: string;
                amount: string;
                destinationStatus: string;
            };
            Deposit: {
                who: string;
                amount: string;
            };
            Withdraw: {
                who: string;
                amount: string;
            };
            Slashed: {
                who: string;
                amount: string;
            };
        };
    };
    /**
     * Lookup34: frame_support::traits::tokens::misc::BalanceStatus
     */
    FrameSupportTokensMiscBalanceStatus: {
        _enum: string[];
    };
    /**
     * Lookup35: pallet_sudo::pallet::Event<T>
     */
    PalletSudoEvent: {
        _enum: {
            Sudid: {
                sudoResult: string;
            };
            KeyChanged: {
                oldSudoer: string;
            };
            SudoAsDone: {
                sudoResult: string;
            };
        };
    };
    /**
     * Lookup37: cumulus_pallet_parachain_system::pallet::Event<T>
     */
    CumulusPalletParachainSystemEvent: {
        _enum: {
            ValidationFunctionStored: string;
            ValidationFunctionApplied: {
                relayChainBlockNum: string;
            };
            ValidationFunctionDiscarded: string;
            UpgradeAuthorized: {
                codeHash: string;
            };
            DownwardMessagesReceived: {
                count: string;
            };
            DownwardMessagesProcessed: {
                weightUsed: string;
                dmqHead: string;
            };
        };
    };
    /**
     * Lookup38: pallet_transaction_payment::pallet::Event<T>
     */
    PalletTransactionPaymentEvent: {
        _enum: {
            TransactionFeePaid: {
                who: string;
                actualFee: string;
                tip: string;
            };
        };
    };
    /**
     * Lookup39: pallet_evm::pallet::Event<T>
     */
    PalletEvmEvent: {
        _enum: {
            Log: {
                log: string;
            };
            Created: {
                address: string;
            };
            CreatedFailed: {
                address: string;
            };
            Executed: {
                address: string;
            };
            ExecutedFailed: {
                address: string;
            };
        };
    };
    /**
     * Lookup40: ethereum::log::Log
     */
    EthereumLog: {
        address: string;
        topics: string;
        data: string;
    };
    /**
     * Lookup43: pallet_ethereum::pallet::Event
     */
    PalletEthereumEvent: {
        _enum: {
            Executed: {
                from: string;
                to: string;
                transactionHash: string;
                exitReason: string;
            };
        };
    };
    /**
     * Lookup44: evm_core::error::ExitReason
     */
    EvmCoreErrorExitReason: {
        _enum: {
            Succeed: string;
            Error: string;
            Revert: string;
            Fatal: string;
        };
    };
    /**
     * Lookup45: evm_core::error::ExitSucceed
     */
    EvmCoreErrorExitSucceed: {
        _enum: string[];
    };
    /**
     * Lookup46: evm_core::error::ExitError
     */
    EvmCoreErrorExitError: {
        _enum: {
            StackUnderflow: string;
            StackOverflow: string;
            InvalidJump: string;
            InvalidRange: string;
            DesignatedInvalid: string;
            CallTooDeep: string;
            CreateCollision: string;
            CreateContractLimit: string;
            OutOfOffset: string;
            OutOfGas: string;
            OutOfFund: string;
            PCUnderflow: string;
            CreateEmpty: string;
            Other: string;
            __Unused14: string;
            InvalidCode: string;
        };
    };
    /**
     * Lookup50: evm_core::error::ExitRevert
     */
    EvmCoreErrorExitRevert: {
        _enum: string[];
    };
    /**
     * Lookup51: evm_core::error::ExitFatal
     */
    EvmCoreErrorExitFatal: {
        _enum: {
            NotSupported: string;
            UnhandledInterrupt: string;
            CallErrorAsFatal: string;
            Other: string;
        };
    };
    /**
     * Lookup52: pallet_parachain_staking::pallet::Event<T>
     */
    PalletParachainStakingEvent: {
        _enum: {
            NewRound: {
                startingBlock: string;
                round: string;
                selectedCollatorsNumber: string;
                totalBalance: string;
            };
            JoinedCollatorCandidates: {
                account: string;
                amountLocked: string;
                newTotalAmtLocked: string;
            };
            CollatorChosen: {
                round: string;
                collatorAccount: string;
                totalExposedAmount: string;
            };
            CandidateBondLessRequested: {
                candidate: string;
                amountToDecrease: string;
                executeRound: string;
            };
            CandidateBondedMore: {
                candidate: string;
                amount: string;
                newTotalBond: string;
            };
            CandidateBondedLess: {
                candidate: string;
                amount: string;
                newBond: string;
            };
            CandidateWentOffline: {
                candidate: string;
            };
            CandidateBackOnline: {
                candidate: string;
            };
            CandidateScheduledExit: {
                exitAllowedRound: string;
                candidate: string;
                scheduledExit: string;
            };
            CancelledCandidateExit: {
                candidate: string;
            };
            CancelledCandidateBondLess: {
                candidate: string;
                amount: string;
                executeRound: string;
            };
            CandidateLeft: {
                exCandidate: string;
                unlockedAmount: string;
                newTotalAmtLocked: string;
            };
            DelegationDecreaseScheduled: {
                delegator: string;
                candidate: string;
                amountToDecrease: string;
                executeRound: string;
            };
            DelegationIncreased: {
                delegator: string;
                candidate: string;
                amount: string;
                inTop: string;
            };
            DelegationDecreased: {
                delegator: string;
                candidate: string;
                amount: string;
                inTop: string;
            };
            DelegatorExitScheduled: {
                round: string;
                delegator: string;
                scheduledExit: string;
            };
            DelegationRevocationScheduled: {
                round: string;
                delegator: string;
                candidate: string;
                scheduledExit: string;
            };
            DelegatorLeft: {
                delegator: string;
                unstakedAmount: string;
            };
            DelegationRevoked: {
                delegator: string;
                candidate: string;
                unstakedAmount: string;
            };
            DelegationKicked: {
                delegator: string;
                candidate: string;
                unstakedAmount: string;
            };
            DelegatorExitCancelled: {
                delegator: string;
            };
            CancelledDelegationRequest: {
                delegator: string;
                cancelledRequest: string;
                collator: string;
            };
            Delegation: {
                delegator: string;
                lockedAmount: string;
                candidate: string;
                delegatorPosition: string;
                autoCompound: string;
            };
            DelegatorLeftCandidate: {
                delegator: string;
                candidate: string;
                unstakedAmount: string;
                totalCandidateStaked: string;
            };
            Rewarded: {
                account: string;
                rewards: string;
            };
            ReservedForParachainBond: {
                account: string;
                value: string;
            };
            ParachainBondAccountSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            ParachainBondReservePercentSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            InflationSet: {
                annualMin: string;
                annualIdeal: string;
                annualMax: string;
                roundMin: string;
                roundIdeal: string;
                roundMax: string;
            };
            StakeExpectationsSet: {
                expectMin: string;
                expectIdeal: string;
                expectMax: string;
            };
            TotalSelectedSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            CollatorCommissionSet: {
                _alias: {
                    new_: string;
                };
                old: string;
                new_: string;
            };
            BlocksPerRoundSet: {
                _alias: {
                    new_: string;
                };
                currentRound: string;
                firstBlock: string;
                old: string;
                new_: string;
                newPerRoundInflationMin: string;
                newPerRoundInflationIdeal: string;
                newPerRoundInflationMax: string;
            };
            AutoCompoundSet: {
                candidate: string;
                delegator: string;
                value: string;
            };
            Compounded: {
                candidate: string;
                delegator: string;
                amount: string;
            };
        };
    };
    /**
     * Lookup54:
     * pallet_parachain_staking::delegation_requests::CancelledScheduledRequest<Balance>
     */
    PalletParachainStakingDelegationRequestsCancelledScheduledRequest: {
        whenExecutable: string;
        action: string;
    };
    /**
     * Lookup55: pallet_parachain_staking::delegation_requests::DelegationAction<Balance>
     */
    PalletParachainStakingDelegationRequestsDelegationAction: {
        _enum: {
            Revoke: string;
            Decrease: string;
        };
    };
    /**
     * Lookup56: pallet_parachain_staking::types::DelegatorAdded<B>
     */
    PalletParachainStakingDelegatorAdded: {
        _enum: {
            AddedToTop: {
                newTotal: string;
            };
            AddedToBottom: string;
        };
    };
    /**
     * Lookup59: pallet_scheduler::pallet::Event<T>
     */
    PalletSchedulerEvent: {
        _enum: {
            Scheduled: {
                when: string;
                index: string;
            };
            Canceled: {
                when: string;
                index: string;
            };
            Dispatched: {
                task: string;
                id: string;
                result: string;
            };
            CallUnavailable: {
                task: string;
                id: string;
            };
            PeriodicFailed: {
                task: string;
                id: string;
            };
            PermanentlyOverweight: {
                task: string;
                id: string;
            };
        };
    };
    /**
     * Lookup62: pallet_democracy::pallet::Event<T>
     */
    PalletDemocracyEvent: {
        _enum: {
            Proposed: {
                proposalIndex: string;
                deposit: string;
            };
            Tabled: {
                proposalIndex: string;
                deposit: string;
            };
            ExternalTabled: string;
            Started: {
                refIndex: string;
                threshold: string;
            };
            Passed: {
                refIndex: string;
            };
            NotPassed: {
                refIndex: string;
            };
            Cancelled: {
                refIndex: string;
            };
            Delegated: {
                who: string;
                target: string;
            };
            Undelegated: {
                account: string;
            };
            Vetoed: {
                who: string;
                proposalHash: string;
                until: string;
            };
            Blacklisted: {
                proposalHash: string;
            };
            Voted: {
                voter: string;
                refIndex: string;
                vote: string;
            };
            Seconded: {
                seconder: string;
                propIndex: string;
            };
            ProposalCanceled: {
                propIndex: string;
            };
        };
    };
    /**
     * Lookup63: pallet_democracy::vote_threshold::VoteThreshold
     */
    PalletDemocracyVoteThreshold: {
        _enum: string[];
    };
    /**
     * Lookup64: pallet_democracy::vote::AccountVote<Balance>
     */
    PalletDemocracyVoteAccountVote: {
        _enum: {
            Standard: {
                vote: string;
                balance: string;
            };
            Split: {
                aye: string;
                nay: string;
            };
        };
    };
    /**
     * Lookup66: pallet_collective::pallet::Event<T, I>
     */
    PalletCollectiveEvent: {
        _enum: {
            Proposed: {
                account: string;
                proposalIndex: string;
                proposalHash: string;
                threshold: string;
            };
            Voted: {
                account: string;
                proposalHash: string;
                voted: string;
                yes: string;
                no: string;
            };
            Approved: {
                proposalHash: string;
            };
            Disapproved: {
                proposalHash: string;
            };
            Executed: {
                proposalHash: string;
                result: string;
            };
            MemberExecuted: {
                proposalHash: string;
                result: string;
            };
            Closed: {
                proposalHash: string;
                yes: string;
                no: string;
            };
        };
    };
    /**
     * Lookup68: pallet_treasury::pallet::Event<T, I>
     */
    PalletTreasuryEvent: {
        _enum: {
            Proposed: {
                proposalIndex: string;
            };
            Spending: {
                budgetRemaining: string;
            };
            Awarded: {
                proposalIndex: string;
                award: string;
                account: string;
            };
            Rejected: {
                proposalIndex: string;
                slashed: string;
            };
            Burnt: {
                burntFunds: string;
            };
            Rollover: {
                rolloverBalance: string;
            };
            Deposit: {
                value: string;
            };
            SpendApproved: {
                proposalIndex: string;
                amount: string;
                beneficiary: string;
            };
        };
    };
    /**
     * Lookup69: pallet_author_slot_filter::pallet::Event
     */
    PalletAuthorSlotFilterEvent: {
        _enum: {
            EligibleUpdated: string;
        };
    };
    /**
     * Lookup71: pallet_crowdloan_rewards::pallet::Event<T>
     */
    PalletCrowdloanRewardsEvent: {
        _enum: {
            InitialPaymentMade: string;
            NativeIdentityAssociated: string;
            RewardsPaid: string;
            RewardAddressUpdated: string;
            InitializedAlreadyInitializedAccount: string;
            InitializedAccountWithNotEnoughContribution: string;
        };
    };
    /**
     * Lookup72: pallet_author_mapping::pallet::Event<T>
     */
    PalletAuthorMappingEvent: {
        _enum: {
            KeysRegistered: {
                _alias: {
                    keys_: string;
                };
                nimbusId: string;
                accountId: string;
                keys_: string;
            };
            KeysRemoved: {
                _alias: {
                    keys_: string;
                };
                nimbusId: string;
                accountId: string;
                keys_: string;
            };
            KeysRotated: {
                newNimbusId: string;
                accountId: string;
                newKeys: string;
            };
        };
    };
    /**
     * Lookup73: nimbus_primitives::nimbus_crypto::Public
     */
    NimbusPrimitivesNimbusCryptoPublic: string;
    /**
     * Lookup74: sp_core::sr25519::Public
     */
    SpCoreSr25519Public: string;
    /**
     * Lookup75: session_keys_primitives::vrf::vrf_crypto::Public
     */
    SessionKeysPrimitivesVrfVrfCryptoPublic: string;
    /**
     * Lookup76: pallet_proxy::pallet::Event<T>
     */
    PalletProxyEvent: {
        _enum: {
            ProxyExecuted: {
                result: string;
            };
            PureCreated: {
                pure: string;
                who: string;
                proxyType: string;
                disambiguationIndex: string;
            };
            Announced: {
                real: string;
                proxy: string;
                callHash: string;
            };
            ProxyAdded: {
                delegator: string;
                delegatee: string;
                proxyType: string;
                delay: string;
            };
            ProxyRemoved: {
                delegator: string;
                delegatee: string;
                proxyType: string;
                delay: string;
            };
        };
    };
    /**
     * Lookup77: moonbase_runtime::ProxyType
     */
    MoonbaseRuntimeProxyType: {
        _enum: string[];
    };
    /**
     * Lookup79: pallet_maintenance_mode::pallet::Event
     */
    PalletMaintenanceModeEvent: {
        _enum: {
            EnteredMaintenanceMode: string;
            NormalOperationResumed: string;
            FailedToSuspendIdleXcmExecution: {
                error: string;
            };
            FailedToResumeIdleXcmExecution: {
                error: string;
            };
        };
    };
    /**
     * Lookup80: pallet_identity::pallet::Event<T>
     */
    PalletIdentityEvent: {
        _enum: {
            IdentitySet: {
                who: string;
            };
            IdentityCleared: {
                who: string;
                deposit: string;
            };
            IdentityKilled: {
                who: string;
                deposit: string;
            };
            JudgementRequested: {
                who: string;
                registrarIndex: string;
            };
            JudgementUnrequested: {
                who: string;
                registrarIndex: string;
            };
            JudgementGiven: {
                target: string;
                registrarIndex: string;
            };
            RegistrarAdded: {
                registrarIndex: string;
            };
            SubIdentityAdded: {
                sub: string;
                main: string;
                deposit: string;
            };
            SubIdentityRemoved: {
                sub: string;
                main: string;
                deposit: string;
            };
            SubIdentityRevoked: {
                sub: string;
                main: string;
                deposit: string;
            };
        };
    };
    /**
     * Lookup81: cumulus_pallet_xcmp_queue::pallet::Event<T>
     */
    CumulusPalletXcmpQueueEvent: {
        _enum: {
            Success: {
                messageHash: string;
                weight: string;
            };
            Fail: {
                messageHash: string;
                error: string;
                weight: string;
            };
            BadVersion: {
                messageHash: string;
            };
            BadFormat: {
                messageHash: string;
            };
            UpwardMessageSent: {
                messageHash: string;
            };
            XcmpMessageSent: {
                messageHash: string;
            };
            OverweightEnqueued: {
                sender: string;
                sentAt: string;
                index: string;
                required: string;
            };
            OverweightServiced: {
                index: string;
                used: string;
            };
        };
    };
    /**
     * Lookup83: xcm::v2::traits::Error
     */
    XcmV2TraitsError: {
        _enum: {
            Overflow: string;
            Unimplemented: string;
            UntrustedReserveLocation: string;
            UntrustedTeleportLocation: string;
            MultiLocationFull: string;
            MultiLocationNotInvertible: string;
            BadOrigin: string;
            InvalidLocation: string;
            AssetNotFound: string;
            FailedToTransactAsset: string;
            NotWithdrawable: string;
            LocationCannotHold: string;
            ExceedsMaxMessageSize: string;
            DestinationUnsupported: string;
            Transport: string;
            Unroutable: string;
            UnknownClaim: string;
            FailedToDecode: string;
            MaxWeightInvalid: string;
            NotHoldingFees: string;
            TooExpensive: string;
            Trap: string;
            UnhandledXcmVersion: string;
            WeightLimitReached: string;
            Barrier: string;
            WeightNotComputable: string;
        };
    };
    /**
     * Lookup85: cumulus_pallet_xcm::pallet::Event<T>
     */
    CumulusPalletXcmEvent: {
        _enum: {
            InvalidFormat: string;
            UnsupportedVersion: string;
            ExecutedDownward: string;
        };
    };
    /**
     * Lookup87: xcm::v2::traits::Outcome
     */
    XcmV2TraitsOutcome: {
        _enum: {
            Complete: string;
            Incomplete: string;
            Error: string;
        };
    };
    /**
     * Lookup88: cumulus_pallet_dmp_queue::pallet::Event<T>
     */
    CumulusPalletDmpQueueEvent: {
        _enum: {
            InvalidFormat: {
                messageId: string;
            };
            UnsupportedVersion: {
                messageId: string;
            };
            ExecutedDownward: {
                messageId: string;
                outcome: string;
            };
            WeightExhausted: {
                messageId: string;
                remainingWeight: string;
                requiredWeight: string;
            };
            OverweightEnqueued: {
                messageId: string;
                overweightIndex: string;
                requiredWeight: string;
            };
            OverweightServiced: {
                overweightIndex: string;
                weightUsed: string;
            };
        };
    };
    /**
     * Lookup89: pallet_xcm::pallet::Event<T>
     */
    PalletXcmEvent: {
        _enum: {
            Attempted: string;
            Sent: string;
            UnexpectedResponse: string;
            ResponseReady: string;
            Notified: string;
            NotifyOverweight: string;
            NotifyDispatchError: string;
            NotifyDecodeFailed: string;
            InvalidResponder: string;
            InvalidResponderVersion: string;
            ResponseTaken: string;
            AssetsTrapped: string;
            VersionChangeNotified: string;
            SupportedVersionChanged: string;
            NotifyTargetSendFail: string;
            NotifyTargetMigrationFail: string;
            AssetsClaimed: string;
        };
    };
    /**
     * Lookup90: xcm::v1::multilocation::MultiLocation
     */
    XcmV1MultiLocation: {
        parents: string;
        interior: string;
    };
    /**
     * Lookup91: xcm::v1::multilocation::Junctions
     */
    XcmV1MultilocationJunctions: {
        _enum: {
            Here: string;
            X1: string;
            X2: string;
            X3: string;
            X4: string;
            X5: string;
            X6: string;
            X7: string;
            X8: string;
        };
    };
    /**
     * Lookup92: xcm::v1::junction::Junction
     */
    XcmV1Junction: {
        _enum: {
            Parachain: string;
            AccountId32: {
                network: string;
                id: string;
            };
            AccountIndex64: {
                network: string;
                index: string;
            };
            AccountKey20: {
                network: string;
                key: string;
            };
            PalletInstance: string;
            GeneralIndex: string;
            GeneralKey: string;
            OnlyChild: string;
            Plurality: {
                id: string;
                part: string;
            };
        };
    };
    /**
     * Lookup94: xcm::v0::junction::NetworkId
     */
    XcmV0JunctionNetworkId: {
        _enum: {
            Any: string;
            Named: string;
            Polkadot: string;
            Kusama: string;
        };
    };
    /**
     * Lookup97: xcm::v0::junction::BodyId
     */
    XcmV0JunctionBodyId: {
        _enum: {
            Unit: string;
            Named: string;
            Index: string;
            Executive: string;
            Technical: string;
            Legislative: string;
            Judicial: string;
        };
    };
    /**
     * Lookup98: xcm::v0::junction::BodyPart
     */
    XcmV0JunctionBodyPart: {
        _enum: {
            Voice: string;
            Members: {
                count: string;
            };
            Fraction: {
                nom: string;
                denom: string;
            };
            AtLeastProportion: {
                nom: string;
                denom: string;
            };
            MoreThanProportion: {
                nom: string;
                denom: string;
            };
        };
    };
    /**
     * Lookup99: xcm::v2::Xcm<RuntimeCall>
     */
    XcmV2Xcm: string;
    /**
     * Lookup101: xcm::v2::Instruction<RuntimeCall>
     */
    XcmV2Instruction: {
        _enum: {
            WithdrawAsset: string;
            ReserveAssetDeposited: string;
            ReceiveTeleportedAsset: string;
            QueryResponse: {
                queryId: string;
                response: string;
                maxWeight: string;
            };
            TransferAsset: {
                assets: string;
                beneficiary: string;
            };
            TransferReserveAsset: {
                assets: string;
                dest: string;
                xcm: string;
            };
            Transact: {
                originType: string;
                requireWeightAtMost: string;
                call: string;
            };
            HrmpNewChannelOpenRequest: {
                sender: string;
                maxMessageSize: string;
                maxCapacity: string;
            };
            HrmpChannelAccepted: {
                recipient: string;
            };
            HrmpChannelClosing: {
                initiator: string;
                sender: string;
                recipient: string;
            };
            ClearOrigin: string;
            DescendOrigin: string;
            ReportError: {
                queryId: string;
                dest: string;
                maxResponseWeight: string;
            };
            DepositAsset: {
                assets: string;
                maxAssets: string;
                beneficiary: string;
            };
            DepositReserveAsset: {
                assets: string;
                maxAssets: string;
                dest: string;
                xcm: string;
            };
            ExchangeAsset: {
                give: string;
                receive: string;
            };
            InitiateReserveWithdraw: {
                assets: string;
                reserve: string;
                xcm: string;
            };
            InitiateTeleport: {
                assets: string;
                dest: string;
                xcm: string;
            };
            QueryHolding: {
                queryId: string;
                dest: string;
                assets: string;
                maxResponseWeight: string;
            };
            BuyExecution: {
                fees: string;
                weightLimit: string;
            };
            RefundSurplus: string;
            SetErrorHandler: string;
            SetAppendix: string;
            ClearError: string;
            ClaimAsset: {
                assets: string;
                ticket: string;
            };
            Trap: string;
            SubscribeVersion: {
                queryId: string;
                maxResponseWeight: string;
            };
            UnsubscribeVersion: string;
        };
    };
    /**
     * Lookup102: xcm::v1::multiasset::MultiAssets
     */
    XcmV1MultiassetMultiAssets: string;
    /**
     * Lookup104: xcm::v1::multiasset::MultiAsset
     */
    XcmV1MultiAsset: {
        id: string;
        fun: string;
    };
    /**
     * Lookup105: xcm::v1::multiasset::AssetId
     */
    XcmV1MultiassetAssetId: {
        _enum: {
            Concrete: string;
            Abstract: string;
        };
    };
    /**
     * Lookup106: xcm::v1::multiasset::Fungibility
     */
    XcmV1MultiassetFungibility: {
        _enum: {
            Fungible: string;
            NonFungible: string;
        };
    };
    /**
     * Lookup107: xcm::v1::multiasset::AssetInstance
     */
    XcmV1MultiassetAssetInstance: {
        _enum: {
            Undefined: string;
            Index: string;
            Array4: string;
            Array8: string;
            Array16: string;
            Array32: string;
            Blob: string;
        };
    };
    /**
     * Lookup109: xcm::v2::Response
     */
    XcmV2Response: {
        _enum: {
            Null: string;
            Assets: string;
            ExecutionResult: string;
            Version: string;
        };
    };
    /**
     * Lookup112: xcm::v0::OriginKind
     */
    XcmV0OriginKind: {
        _enum: string[];
    };
    /**
     * Lookup113: xcm::double_encoded::DoubleEncoded<T>
     */
    XcmDoubleEncoded: {
        encoded: string;
    };
    /**
     * Lookup114: xcm::v1::multiasset::MultiAssetFilter
     */
    XcmV1MultiassetMultiAssetFilter: {
        _enum: {
            Definite: string;
            Wild: string;
        };
    };
    /**
     * Lookup115: xcm::v1::multiasset::WildMultiAsset
     */
    XcmV1MultiassetWildMultiAsset: {
        _enum: {
            All: string;
            AllOf: {
                id: string;
                fun: string;
            };
        };
    };
    /**
     * Lookup116: xcm::v1::multiasset::WildFungibility
     */
    XcmV1MultiassetWildFungibility: {
        _enum: string[];
    };
    /**
     * Lookup117: xcm::v2::WeightLimit
     */
    XcmV2WeightLimit: {
        _enum: {
            Unlimited: string;
            Limited: string;
        };
    };
    /**
     * Lookup119: xcm::VersionedMultiAssets
     */
    XcmVersionedMultiAssets: {
        _enum: {
            V0: string;
            V1: string;
        };
    };
    /**
     * Lookup121: xcm::v0::multi_asset::MultiAsset
     */
    XcmV0MultiAsset: {
        _enum: {
            None: string;
            All: string;
            AllFungible: string;
            AllNonFungible: string;
            AllAbstractFungible: {
                id: string;
            };
            AllAbstractNonFungible: {
                class: string;
            };
            AllConcreteFungible: {
                id: string;
            };
            AllConcreteNonFungible: {
                class: string;
            };
            AbstractFungible: {
                id: string;
                amount: string;
            };
            AbstractNonFungible: {
                class: string;
                instance: string;
            };
            ConcreteFungible: {
                id: string;
                amount: string;
            };
            ConcreteNonFungible: {
                class: string;
                instance: string;
            };
        };
    };
    /**
     * Lookup122: xcm::v0::multi_location::MultiLocation
     */
    XcmV0MultiLocation: {
        _enum: {
            Null: string;
            X1: string;
            X2: string;
            X3: string;
            X4: string;
            X5: string;
            X6: string;
            X7: string;
            X8: string;
        };
    };
    /**
     * Lookup123: xcm::v0::junction::Junction
     */
    XcmV0Junction: {
        _enum: {
            Parent: string;
            Parachain: string;
            AccountId32: {
                network: string;
                id: string;
            };
            AccountIndex64: {
                network: string;
                index: string;
            };
            AccountKey20: {
                network: string;
                key: string;
            };
            PalletInstance: string;
            GeneralIndex: string;
            GeneralKey: string;
            OnlyChild: string;
            Plurality: {
                id: string;
                part: string;
            };
        };
    };
    /**
     * Lookup124: xcm::VersionedMultiLocation
     */
    XcmVersionedMultiLocation: {
        _enum: {
            V0: string;
            V1: string;
        };
    };
    /**
     * Lookup125: pallet_assets::pallet::Event<T, I>
     */
    PalletAssetsEvent: {
        _enum: {
            Created: {
                assetId: string;
                creator: string;
                owner: string;
            };
            Issued: {
                assetId: string;
                owner: string;
                totalSupply: string;
            };
            Transferred: {
                assetId: string;
                from: string;
                to: string;
                amount: string;
            };
            Burned: {
                assetId: string;
                owner: string;
                balance: string;
            };
            TeamChanged: {
                assetId: string;
                issuer: string;
                admin: string;
                freezer: string;
            };
            OwnerChanged: {
                assetId: string;
                owner: string;
            };
            Frozen: {
                assetId: string;
                who: string;
            };
            Thawed: {
                assetId: string;
                who: string;
            };
            AssetFrozen: {
                assetId: string;
            };
            AssetThawed: {
                assetId: string;
            };
            Destroyed: {
                assetId: string;
            };
            ForceCreated: {
                assetId: string;
                owner: string;
            };
            MetadataSet: {
                assetId: string;
                name: string;
                symbol: string;
                decimals: string;
                isFrozen: string;
            };
            MetadataCleared: {
                assetId: string;
            };
            ApprovedTransfer: {
                assetId: string;
                source: string;
                delegate: string;
                amount: string;
            };
            ApprovalCancelled: {
                assetId: string;
                owner: string;
                delegate: string;
            };
            TransferredApproved: {
                assetId: string;
                owner: string;
                delegate: string;
                destination: string;
                amount: string;
            };
            AssetStatusChanged: {
                assetId: string;
            };
        };
    };
    /**
     * Lookup126: orml_xtokens::module::Event<T>
     */
    OrmlXtokensModuleEvent: {
        _enum: {
            TransferredMultiAssets: {
                sender: string;
                assets: string;
                fee: string;
                dest: string;
            };
        };
    };
    /**
     * Lookup127: pallet_asset_manager::pallet::Event<T>
     */
    PalletAssetManagerEvent: {
        _enum: {
            ForeignAssetRegistered: {
                assetId: string;
                asset: string;
                metadata: string;
            };
            UnitsPerSecondChanged: {
                assetType: string;
                unitsPerSecond: string;
            };
            ForeignAssetTypeChanged: {
                assetId: string;
                newAssetType: string;
            };
            ForeignAssetRemoved: {
                assetId: string;
                assetType: string;
            };
            SupportedAssetRemoved: {
                assetType: string;
            };
            LocalAssetRegistered: {
                assetId: string;
                creator: string;
                owner: string;
            };
            ForeignAssetDestroyed: {
                assetId: string;
                assetType: string;
            };
            LocalAssetDestroyed: {
                assetId: string;
            };
        };
    };
    /**
     * Lookup128: moonbase_runtime::xcm_config::AssetType
     */
    MoonbaseRuntimeXcmConfigAssetType: {
        _enum: {
            Xcm: string;
        };
    };
    /**
     * Lookup129: moonbase_runtime::asset_config::AssetRegistrarMetadata
     */
    MoonbaseRuntimeAssetConfigAssetRegistrarMetadata: {
        name: string;
        symbol: string;
        decimals: string;
        isFrozen: string;
    };
    /**
     * Lookup130: pallet_migrations::pallet::Event<T>
     */
    PalletMigrationsEvent: {
        _enum: {
            RuntimeUpgradeStarted: string;
            RuntimeUpgradeCompleted: {
                weight: string;
            };
            MigrationStarted: {
                migrationName: string;
            };
            MigrationCompleted: {
                migrationName: string;
                consumedWeight: string;
            };
            FailedToSuspendIdleXcmExecution: {
                error: string;
            };
            FailedToResumeIdleXcmExecution: {
                error: string;
            };
        };
    };
    /**
     * Lookup131: pallet_xcm_transactor::pallet::Event<T>
     */
    PalletXcmTransactorEvent: {
        _enum: {
            TransactedDerivative: {
                accountId: string;
                dest: string;
                call: string;
                index: string;
            };
            TransactedSovereign: {
                feePayer: string;
                dest: string;
                call: string;
            };
            TransactedSigned: {
                feePayer: string;
                dest: string;
                call: string;
            };
            RegisteredDerivative: {
                accountId: string;
                index: string;
            };
            DeRegisteredDerivative: {
                index: string;
            };
            TransactFailed: {
                error: string;
            };
            TransactInfoChanged: {
                location: string;
                remoteInfo: string;
            };
            TransactInfoRemoved: {
                location: string;
            };
            DestFeePerSecondChanged: {
                location: string;
                feePerSecond: string;
            };
            DestFeePerSecondRemoved: {
                location: string;
            };
            HrmpManagementSent: {
                action: string;
            };
        };
    };
    /**
     * Lookup132: pallet_xcm_transactor::pallet::RemoteTransactInfoWithMaxWeight
     */
    PalletXcmTransactorRemoteTransactInfoWithMaxWeight: {
        transactExtraWeight: string;
        maxWeight: string;
        transactExtraWeightSigned: string;
    };
    /**
     * Lookup134: pallet_xcm_transactor::pallet::HrmpOperation
     */
    PalletXcmTransactorHrmpOperation: {
        _enum: {
            InitOpen: string;
            Accept: {
                paraId: string;
            };
            Close: string;
        };
    };
    /**
     * Lookup135: pallet_xcm_transactor::pallet::HrmpInitParams
     */
    PalletXcmTransactorHrmpInitParams: {
        paraId: string;
        proposedMaxCapacity: string;
        proposedMaxMessageSize: string;
    };
    /**
     * Lookup136: polkadot_parachain::primitives::HrmpChannelId
     */
    PolkadotParachainPrimitivesHrmpChannelId: {
        sender: string;
        recipient: string;
    };
    /**
     * Lookup138: pallet_moonbeam_orbiters::pallet::Event<T>
     */
    PalletMoonbeamOrbitersEvent: {
        _enum: {
            OrbiterJoinCollatorPool: {
                collator: string;
                orbiter: string;
            };
            OrbiterLeaveCollatorPool: {
                collator: string;
                orbiter: string;
            };
            OrbiterRewarded: {
                account: string;
                rewards: string;
            };
            OrbiterRotation: {
                collator: string;
                oldOrbiter: string;
                newOrbiter: string;
            };
            OrbiterRegistered: {
                account: string;
                deposit: string;
            };
            OrbiterUnregistered: {
                account: string;
            };
        };
    };
    /**
     * Lookup139: pallet_randomness::pallet::Event<T>
     */
    PalletRandomnessEvent: {
        _enum: {
            RandomnessRequestedBabeEpoch: {
                id: string;
                refundAddress: string;
                contractAddress: string;
                fee: string;
                gasLimit: string;
                numWords: string;
                salt: string;
                earliestEpoch: string;
            };
            RandomnessRequestedLocal: {
                id: string;
                refundAddress: string;
                contractAddress: string;
                fee: string;
                gasLimit: string;
                numWords: string;
                salt: string;
                earliestBlock: string;
            };
            RequestFulfilled: {
                id: string;
            };
            RequestFeeIncreased: {
                id: string;
                newFee: string;
            };
            RequestExpirationExecuted: {
                id: string;
            };
        };
    };
    /**
     * Lookup141: pallet_conviction_voting::pallet::Event<T, I>
     */
    PalletConvictionVotingEvent: {
        _enum: {
            Delegated: string;
            Undelegated: string;
        };
    };
    /**
     * Lookup142: pallet_referenda::pallet::Event<T, I>
     */
    PalletReferendaEvent: {
        _enum: {
            Submitted: {
                index: string;
                track: string;
                proposal: string;
            };
            DecisionDepositPlaced: {
                index: string;
                who: string;
                amount: string;
            };
            DecisionDepositRefunded: {
                index: string;
                who: string;
                amount: string;
            };
            DepositSlashed: {
                who: string;
                amount: string;
            };
            DecisionStarted: {
                index: string;
                track: string;
                proposal: string;
                tally: string;
            };
            ConfirmStarted: {
                index: string;
            };
            ConfirmAborted: {
                index: string;
            };
            Confirmed: {
                index: string;
                tally: string;
            };
            Approved: {
                index: string;
            };
            Rejected: {
                index: string;
                tally: string;
            };
            TimedOut: {
                index: string;
                tally: string;
            };
            Cancelled: {
                index: string;
                tally: string;
            };
            Killed: {
                index: string;
                tally: string;
            };
        };
    };
    /**
     * Lookup143: frame_support::traits::preimages::Bounded<moonbase_runtime::RuntimeCall>
     */
    FrameSupportPreimagesBounded: {
        _enum: {
            Legacy: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
            Inline: string;
            Lookup: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
                len: string;
            };
        };
    };
    /**
     * Lookup145: frame_system::pallet::Call<T>
     */
    FrameSystemCall: {
        _enum: {
            fill_block: {
                ratio: string;
            };
            remark: {
                remark: string;
            };
            set_heap_pages: {
                pages: string;
            };
            set_code: {
                code: string;
            };
            set_code_without_checks: {
                code: string;
            };
            set_storage: {
                items: string;
            };
            kill_storage: {
                _alias: {
                    keys_: string;
                };
                keys_: string;
            };
            kill_prefix: {
                prefix: string;
                subkeys: string;
            };
            remark_with_event: {
                remark: string;
            };
        };
    };
    /**
     * Lookup149: pallet_utility::pallet::Call<T>
     */
    PalletUtilityCall: {
        _enum: {
            batch: {
                calls: string;
            };
            as_derivative: {
                index: string;
                call: string;
            };
            batch_all: {
                calls: string;
            };
            dispatch_as: {
                asOrigin: string;
                call: string;
            };
            force_batch: {
                calls: string;
            };
        };
    };
    /**
     * Lookup151: moonbase_runtime::OriginCaller
     */
    MoonbaseRuntimeOriginCaller: {
        _enum: {
            system: string;
            __Unused1: string;
            __Unused2: string;
            __Unused3: string;
            __Unused4: string;
            __Unused5: string;
            __Unused6: string;
            __Unused7: string;
            __Unused8: string;
            __Unused9: string;
            Void: string;
            Ethereum: string;
            __Unused12: string;
            __Unused13: string;
            __Unused14: string;
            CouncilCollective: string;
            TechCommitteeCollective: string;
            __Unused17: string;
            __Unused18: string;
            __Unused19: string;
            __Unused20: string;
            __Unused21: string;
            __Unused22: string;
            __Unused23: string;
            __Unused24: string;
            __Unused25: string;
            CumulusXcm: string;
            __Unused27: string;
            PolkadotXcm: string;
            __Unused29: string;
            __Unused30: string;
            __Unused31: string;
            __Unused32: string;
            __Unused33: string;
            __Unused34: string;
            __Unused35: string;
            __Unused36: string;
            __Unused37: string;
            EthereumXcm: string;
            __Unused39: string;
            TreasuryCouncilCollective: string;
            __Unused41: string;
            __Unused42: string;
            Origins: string;
            __Unused44: string;
            __Unused45: string;
            OpenTechCommitteeCollective: string;
        };
    };
    /**
     * Lookup152:
     * frame_support::dispatch::RawOrigin[account::AccountId20](account::AccountId20)
     */
    FrameSupportDispatchRawOrigin: {
        _enum: {
            Root: string;
            Signed: string;
            None: string;
        };
    };
    /**
     * Lookup153: pallet_ethereum::RawOrigin
     */
    PalletEthereumRawOrigin: {
        _enum: {
            EthereumTransaction: string;
        };
    };
    /**
     * Lookup154: pallet_collective::RawOrigin<account::AccountId20, I>
     */
    PalletCollectiveRawOrigin: {
        _enum: {
            Members: string;
            Member: string;
            _Phantom: string;
        };
    };
    /**
     * Lookup156: cumulus_pallet_xcm::pallet::Origin
     */
    CumulusPalletXcmOrigin: {
        _enum: {
            Relay: string;
            SiblingParachain: string;
        };
    };
    /**
     * Lookup157: pallet_xcm::pallet::Origin
     */
    PalletXcmOrigin: {
        _enum: {
            Xcm: string;
            Response: string;
        };
    };
    /**
     * Lookup158: pallet_ethereum_xcm::RawOrigin
     */
    PalletEthereumXcmRawOrigin: {
        _enum: {
            XcmEthereumTransaction: string;
        };
    };
    /**
     * Lookup160: moonbase_runtime::governance::origins::custom_origins::Origin
     */
    MoonbaseRuntimeGovernanceOriginsCustomOriginsOrigin: {
        _enum: string[];
    };
    /**
     * Lookup162: sp_core::Void
     */
    SpCoreVoid: string;
    /**
     * Lookup163: pallet_timestamp::pallet::Call<T>
     */
    PalletTimestampCall: {
        _enum: {
            set: {
                now: string;
            };
        };
    };
    /**
     * Lookup164: pallet_balances::pallet::Call<T, I>
     */
    PalletBalancesCall: {
        _enum: {
            transfer: {
                dest: string;
                value: string;
            };
            set_balance: {
                who: string;
                newFree: string;
                newReserved: string;
            };
            force_transfer: {
                source: string;
                dest: string;
                value: string;
            };
            transfer_keep_alive: {
                dest: string;
                value: string;
            };
            transfer_all: {
                dest: string;
                keepAlive: string;
            };
            force_unreserve: {
                who: string;
                amount: string;
            };
        };
    };
    /**
     * Lookup165: pallet_sudo::pallet::Call<T>
     */
    PalletSudoCall: {
        _enum: {
            sudo: {
                call: string;
            };
            sudo_unchecked_weight: {
                call: string;
                weight: string;
            };
            set_key: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            sudo_as: {
                who: string;
                call: string;
            };
        };
    };
    /**
     * Lookup166: cumulus_pallet_parachain_system::pallet::Call<T>
     */
    CumulusPalletParachainSystemCall: {
        _enum: {
            set_validation_data: {
                data: string;
            };
            sudo_send_upward_message: {
                message: string;
            };
            authorize_upgrade: {
                codeHash: string;
            };
            enact_authorized_upgrade: {
                code: string;
            };
        };
    };
    /**
     * Lookup167: cumulus_primitives_parachain_inherent::ParachainInherentData
     */
    CumulusPrimitivesParachainInherentParachainInherentData: {
        validationData: string;
        relayChainState: string;
        downwardMessages: string;
        horizontalMessages: string;
    };
    /**
     * Lookup168: polkadot_primitives::v2::PersistedValidationData<primitive_types::H256, N>
     */
    PolkadotPrimitivesV2PersistedValidationData: {
        parentHead: string;
        relayParentNumber: string;
        relayParentStorageRoot: string;
        maxPovSize: string;
    };
    /**
     * Lookup170: sp_trie::storage_proof::StorageProof
     */
    SpTrieStorageProof: {
        trieNodes: string;
    };
    /**
     * Lookup173: polkadot_core_primitives::InboundDownwardMessage<BlockNumber>
     */
    PolkadotCorePrimitivesInboundDownwardMessage: {
        sentAt: string;
        msg: string;
    };
    /**
     * Lookup176: polkadot_core_primitives::InboundHrmpMessage<BlockNumber>
     */
    PolkadotCorePrimitivesInboundHrmpMessage: {
        sentAt: string;
        data: string;
    };
    /**
     * Lookup179: pallet_evm::pallet::Call<T>
     */
    PalletEvmCall: {
        _enum: {
            withdraw: {
                address: string;
                value: string;
            };
            call: {
                source: string;
                target: string;
                input: string;
                value: string;
                gasLimit: string;
                maxFeePerGas: string;
                maxPriorityFeePerGas: string;
                nonce: string;
                accessList: string;
            };
            create: {
                source: string;
                init: string;
                value: string;
                gasLimit: string;
                maxFeePerGas: string;
                maxPriorityFeePerGas: string;
                nonce: string;
                accessList: string;
            };
            create2: {
                source: string;
                init: string;
                salt: string;
                value: string;
                gasLimit: string;
                maxFeePerGas: string;
                maxPriorityFeePerGas: string;
                nonce: string;
                accessList: string;
            };
        };
    };
    /**
     * Lookup185: pallet_ethereum::pallet::Call<T>
     */
    PalletEthereumCall: {
        _enum: {
            transact: {
                transaction: string;
            };
        };
    };
    /**
     * Lookup186: ethereum::transaction::TransactionV2
     */
    EthereumTransactionTransactionV2: {
        _enum: {
            Legacy: string;
            EIP2930: string;
            EIP1559: string;
        };
    };
    /**
     * Lookup187: ethereum::transaction::LegacyTransaction
     */
    EthereumTransactionLegacyTransaction: {
        nonce: string;
        gasPrice: string;
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        signature: string;
    };
    /**
     * Lookup188: ethereum::transaction::TransactionAction
     */
    EthereumTransactionTransactionAction: {
        _enum: {
            Call: string;
            Create: string;
        };
    };
    /**
     * Lookup189: ethereum::transaction::TransactionSignature
     */
    EthereumTransactionTransactionSignature: {
        v: string;
        r: string;
        s: string;
    };
    /**
     * Lookup191: ethereum::transaction::EIP2930Transaction
     */
    EthereumTransactionEip2930Transaction: {
        chainId: string;
        nonce: string;
        gasPrice: string;
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        accessList: string;
        oddYParity: string;
        r: string;
        s: string;
    };
    /**
     * Lookup193: ethereum::transaction::AccessListItem
     */
    EthereumTransactionAccessListItem: {
        address: string;
        storageKeys: string;
    };
    /**
     * Lookup194: ethereum::transaction::EIP1559Transaction
     */
    EthereumTransactionEip1559Transaction: {
        chainId: string;
        nonce: string;
        maxPriorityFeePerGas: string;
        maxFeePerGas: string;
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        accessList: string;
        oddYParity: string;
        r: string;
        s: string;
    };
    /**
     * Lookup195: pallet_parachain_staking::pallet::Call<T>
     */
    PalletParachainStakingCall: {
        _enum: {
            set_staking_expectations: {
                expectations: {
                    min: string;
                    ideal: string;
                    max: string;
                };
            };
            set_inflation: {
                schedule: {
                    min: string;
                    ideal: string;
                    max: string;
                };
            };
            set_parachain_bond_account: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_parachain_bond_reserve_percent: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_total_selected: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_collator_commission: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            set_blocks_per_round: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            join_candidates: {
                bond: string;
                candidateCount: string;
            };
            schedule_leave_candidates: {
                candidateCount: string;
            };
            execute_leave_candidates: {
                candidate: string;
                candidateDelegationCount: string;
            };
            cancel_leave_candidates: {
                candidateCount: string;
            };
            go_offline: string;
            go_online: string;
            candidate_bond_more: {
                more: string;
            };
            schedule_candidate_bond_less: {
                less: string;
            };
            execute_candidate_bond_less: {
                candidate: string;
            };
            cancel_candidate_bond_less: string;
            delegate: {
                candidate: string;
                amount: string;
                candidateDelegationCount: string;
                delegationCount: string;
            };
            delegate_with_auto_compound: {
                candidate: string;
                amount: string;
                autoCompound: string;
                candidateDelegationCount: string;
                candidateAutoCompoundingDelegationCount: string;
                delegationCount: string;
            };
            schedule_leave_delegators: string;
            execute_leave_delegators: {
                delegator: string;
                delegationCount: string;
            };
            cancel_leave_delegators: string;
            schedule_revoke_delegation: {
                collator: string;
            };
            delegator_bond_more: {
                candidate: string;
                more: string;
            };
            schedule_delegator_bond_less: {
                candidate: string;
                less: string;
            };
            execute_delegation_request: {
                delegator: string;
                candidate: string;
            };
            cancel_delegation_request: {
                candidate: string;
            };
            set_auto_compound: {
                candidate: string;
                value: string;
                candidateAutoCompoundingDelegationCountHint: string;
                delegationCountHint: string;
            };
            hotfix_remove_delegation_requests_exited_candidates: {
                candidates: string;
            };
        };
    };
    /**
     * Lookup199: pallet_scheduler::pallet::Call<T>
     */
    PalletSchedulerCall: {
        _enum: {
            schedule: {
                when: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
            cancel: {
                when: string;
                index: string;
            };
            schedule_named: {
                id: string;
                when: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
            cancel_named: {
                id: string;
            };
            schedule_after: {
                after: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
            schedule_named_after: {
                id: string;
                after: string;
                maybePeriodic: string;
                priority: string;
                call: string;
            };
        };
    };
    /**
     * Lookup201: pallet_democracy::pallet::Call<T>
     */
    PalletDemocracyCall: {
        _enum: {
            propose: {
                proposal: string;
                value: string;
            };
            second: {
                proposal: string;
            };
            vote: {
                refIndex: string;
                vote: string;
            };
            emergency_cancel: {
                refIndex: string;
            };
            external_propose: {
                proposal: string;
            };
            external_propose_majority: {
                proposal: string;
            };
            external_propose_default: {
                proposal: string;
            };
            fast_track: {
                proposalHash: string;
                votingPeriod: string;
                delay: string;
            };
            veto_external: {
                proposalHash: string;
            };
            cancel_referendum: {
                refIndex: string;
            };
            delegate: {
                to: string;
                conviction: string;
                balance: string;
            };
            undelegate: string;
            clear_public_proposals: string;
            unlock: {
                target: string;
            };
            remove_vote: {
                index: string;
            };
            remove_other_vote: {
                target: string;
                index: string;
            };
            blacklist: {
                proposalHash: string;
                maybeRefIndex: string;
            };
            cancel_proposal: {
                propIndex: string;
            };
        };
    };
    /**
     * Lookup202: pallet_democracy::conviction::Conviction
     */
    PalletDemocracyConviction: {
        _enum: string[];
    };
    /**
     * Lookup204: pallet_collective::pallet::Call<T, I>
     */
    PalletCollectiveCall: {
        _enum: {
            set_members: {
                newMembers: string;
                prime: string;
                oldCount: string;
            };
            execute: {
                proposal: string;
                lengthBound: string;
            };
            propose: {
                threshold: string;
                proposal: string;
                lengthBound: string;
            };
            vote: {
                proposal: string;
                index: string;
                approve: string;
            };
            close_old_weight: {
                proposalHash: string;
                index: string;
                proposalWeightBound: string;
                lengthBound: string;
            };
            disapprove_proposal: {
                proposalHash: string;
            };
            close: {
                proposalHash: string;
                index: string;
                proposalWeightBound: string;
                lengthBound: string;
            };
        };
    };
    /**
     * Lookup208: pallet_treasury::pallet::Call<T, I>
     */
    PalletTreasuryCall: {
        _enum: {
            propose_spend: {
                value: string;
                beneficiary: string;
            };
            reject_proposal: {
                proposalId: string;
            };
            approve_proposal: {
                proposalId: string;
            };
            spend: {
                amount: string;
                beneficiary: string;
            };
            remove_approval: {
                proposalId: string;
            };
        };
    };
    /**
     * Lookup209: pallet_author_inherent::pallet::Call<T>
     */
    PalletAuthorInherentCall: {
        _enum: string[];
    };
    /**
     * Lookup210: pallet_author_slot_filter::pallet::Call<T>
     */
    PalletAuthorSlotFilterCall: {
        _enum: {
            set_eligible: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
        };
    };
    /**
     * Lookup211: pallet_crowdloan_rewards::pallet::Call<T>
     */
    PalletCrowdloanRewardsCall: {
        _enum: {
            associate_native_identity: {
                rewardAccount: string;
                relayAccount: string;
                proof: string;
            };
            change_association_with_relay_keys: {
                rewardAccount: string;
                previousAccount: string;
                proofs: string;
            };
            claim: string;
            update_reward_address: {
                newRewardAccount: string;
            };
            complete_initialization: {
                leaseEndingBlock: string;
            };
            initialize_reward_vec: {
                rewards: string;
            };
        };
    };
    /**
     * Lookup212: sp_runtime::MultiSignature
     */
    SpRuntimeMultiSignature: {
        _enum: {
            Ed25519: string;
            Sr25519: string;
            Ecdsa: string;
        };
    };
    /**
     * Lookup213: sp_core::ed25519::Signature
     */
    SpCoreEd25519Signature: string;
    /**
     * Lookup215: sp_core::sr25519::Signature
     */
    SpCoreSr25519Signature: string;
    /**
     * Lookup216: sp_core::ecdsa::Signature
     */
    SpCoreEcdsaSignature: string;
    /**
     * Lookup222: pallet_author_mapping::pallet::Call<T>
     */
    PalletAuthorMappingCall: {
        _enum: {
            add_association: {
                nimbusId: string;
            };
            update_association: {
                oldNimbusId: string;
                newNimbusId: string;
            };
            clear_association: {
                nimbusId: string;
            };
            remove_keys: string;
            set_keys: {
                _alias: {
                    keys_: string;
                };
                keys_: string;
            };
        };
    };
    /**
     * Lookup223: pallet_proxy::pallet::Call<T>
     */
    PalletProxyCall: {
        _enum: {
            proxy: {
                real: string;
                forceProxyType: string;
                call: string;
            };
            add_proxy: {
                delegate: string;
                proxyType: string;
                delay: string;
            };
            remove_proxy: {
                delegate: string;
                proxyType: string;
                delay: string;
            };
            remove_proxies: string;
            create_pure: {
                proxyType: string;
                delay: string;
                index: string;
            };
            kill_pure: {
                spawner: string;
                proxyType: string;
                index: string;
                height: string;
                extIndex: string;
            };
            announce: {
                real: string;
                callHash: string;
            };
            remove_announcement: {
                real: string;
                callHash: string;
            };
            reject_announcement: {
                delegate: string;
                callHash: string;
            };
            proxy_announced: {
                delegate: string;
                real: string;
                forceProxyType: string;
                call: string;
            };
        };
    };
    /**
     * Lookup225: pallet_maintenance_mode::pallet::Call<T>
     */
    PalletMaintenanceModeCall: {
        _enum: string[];
    };
    /**
     * Lookup226: pallet_identity::pallet::Call<T>
     */
    PalletIdentityCall: {
        _enum: {
            add_registrar: {
                account: string;
            };
            set_identity: {
                info: string;
            };
            set_subs: {
                subs: string;
            };
            clear_identity: string;
            request_judgement: {
                regIndex: string;
                maxFee: string;
            };
            cancel_request: {
                regIndex: string;
            };
            set_fee: {
                index: string;
                fee: string;
            };
            set_account_id: {
                _alias: {
                    new_: string;
                };
                index: string;
                new_: string;
            };
            set_fields: {
                index: string;
                fields: string;
            };
            provide_judgement: {
                regIndex: string;
                target: string;
                judgement: string;
                identity: string;
            };
            kill_identity: {
                target: string;
            };
            add_sub: {
                sub: string;
                data: string;
            };
            rename_sub: {
                sub: string;
                data: string;
            };
            remove_sub: {
                sub: string;
            };
            quit_sub: string;
        };
    };
    /**
     * Lookup227: pallet_identity::types::IdentityInfo<FieldLimit>
     */
    PalletIdentityIdentityInfo: {
        additional: string;
        display: string;
        legal: string;
        web: string;
        riot: string;
        email: string;
        pgpFingerprint: string;
        image: string;
        twitter: string;
    };
    /**
     * Lookup263: pallet_identity::types::BitFlags<pallet_identity::types::IdentityField>
     */
    PalletIdentityBitFlags: {
        _bitLength: number;
        Display: number;
        Legal: number;
        Web: number;
        Riot: number;
        Email: number;
        PgpFingerprint: number;
        Image: number;
        Twitter: number;
    };
    /**
     * Lookup264: pallet_identity::types::IdentityField
     */
    PalletIdentityIdentityField: {
        _enum: string[];
    };
    /**
     * Lookup265: pallet_identity::types::Judgement<Balance>
     */
    PalletIdentityJudgement: {
        _enum: {
            Unknown: string;
            FeePaid: string;
            Reasonable: string;
            KnownGood: string;
            OutOfDate: string;
            LowQuality: string;
            Erroneous: string;
        };
    };
    /**
     * Lookup266: cumulus_pallet_xcmp_queue::pallet::Call<T>
     */
    CumulusPalletXcmpQueueCall: {
        _enum: {
            service_overweight: {
                index: string;
                weightLimit: string;
            };
            suspend_xcm_execution: string;
            resume_xcm_execution: string;
            update_suspend_threshold: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_drop_threshold: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_resume_threshold: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_threshold_weight: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_weight_restrict_decay: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
            update_xcmp_max_individual_weight: {
                _alias: {
                    new_: string;
                };
                new_: string;
            };
        };
    };
    /**
     * Lookup267: cumulus_pallet_dmp_queue::pallet::Call<T>
     */
    CumulusPalletDmpQueueCall: {
        _enum: {
            service_overweight: {
                index: string;
                weightLimit: string;
            };
        };
    };
    /**
     * Lookup268: pallet_xcm::pallet::Call<T>
     */
    PalletXcmCall: {
        _enum: {
            send: {
                dest: string;
                message: string;
            };
            teleport_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
            };
            reserve_transfer_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
            };
            execute: {
                message: string;
                maxWeight: string;
            };
            force_xcm_version: {
                location: string;
                xcmVersion: string;
            };
            force_default_xcm_version: {
                maybeXcmVersion: string;
            };
            force_subscribe_version_notify: {
                location: string;
            };
            force_unsubscribe_version_notify: {
                location: string;
            };
            limited_reserve_transfer_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
                weightLimit: string;
            };
            limited_teleport_assets: {
                dest: string;
                beneficiary: string;
                assets: string;
                feeAssetItem: string;
                weightLimit: string;
            };
        };
    };
    /**
     * Lookup269: xcm::VersionedXcm<RuntimeCall>
     */
    XcmVersionedXcm: {
        _enum: {
            V0: string;
            V1: string;
            V2: string;
        };
    };
    /**
     * Lookup270: xcm::v0::Xcm<RuntimeCall>
     */
    XcmV0Xcm: {
        _enum: {
            WithdrawAsset: {
                assets: string;
                effects: string;
            };
            ReserveAssetDeposit: {
                assets: string;
                effects: string;
            };
            TeleportAsset: {
                assets: string;
                effects: string;
            };
            QueryResponse: {
                queryId: string;
                response: string;
            };
            TransferAsset: {
                assets: string;
                dest: string;
            };
            TransferReserveAsset: {
                assets: string;
                dest: string;
                effects: string;
            };
            Transact: {
                originType: string;
                requireWeightAtMost: string;
                call: string;
            };
            HrmpNewChannelOpenRequest: {
                sender: string;
                maxMessageSize: string;
                maxCapacity: string;
            };
            HrmpChannelAccepted: {
                recipient: string;
            };
            HrmpChannelClosing: {
                initiator: string;
                sender: string;
                recipient: string;
            };
            RelayedFrom: {
                who: string;
                message: string;
            };
        };
    };
    /**
     * Lookup272: xcm::v0::order::Order<RuntimeCall>
     */
    XcmV0Order: {
        _enum: {
            Null: string;
            DepositAsset: {
                assets: string;
                dest: string;
            };
            DepositReserveAsset: {
                assets: string;
                dest: string;
                effects: string;
            };
            ExchangeAsset: {
                give: string;
                receive: string;
            };
            InitiateReserveWithdraw: {
                assets: string;
                reserve: string;
                effects: string;
            };
            InitiateTeleport: {
                assets: string;
                dest: string;
                effects: string;
            };
            QueryHolding: {
                queryId: string;
                dest: string;
                assets: string;
            };
            BuyExecution: {
                fees: string;
                weight: string;
                debt: string;
                haltOnError: string;
                xcm: string;
            };
        };
    };
    /**
     * Lookup274: xcm::v0::Response
     */
    XcmV0Response: {
        _enum: {
            Assets: string;
        };
    };
    /**
     * Lookup275: xcm::v1::Xcm<RuntimeCall>
     */
    XcmV1Xcm: {
        _enum: {
            WithdrawAsset: {
                assets: string;
                effects: string;
            };
            ReserveAssetDeposited: {
                assets: string;
                effects: string;
            };
            ReceiveTeleportedAsset: {
                assets: string;
                effects: string;
            };
            QueryResponse: {
                queryId: string;
                response: string;
            };
            TransferAsset: {
                assets: string;
                beneficiary: string;
            };
            TransferReserveAsset: {
                assets: string;
                dest: string;
                effects: string;
            };
            Transact: {
                originType: string;
                requireWeightAtMost: string;
                call: string;
            };
            HrmpNewChannelOpenRequest: {
                sender: string;
                maxMessageSize: string;
                maxCapacity: string;
            };
            HrmpChannelAccepted: {
                recipient: string;
            };
            HrmpChannelClosing: {
                initiator: string;
                sender: string;
                recipient: string;
            };
            RelayedFrom: {
                who: string;
                message: string;
            };
            SubscribeVersion: {
                queryId: string;
                maxResponseWeight: string;
            };
            UnsubscribeVersion: string;
        };
    };
    /**
     * Lookup277: xcm::v1::order::Order<RuntimeCall>
     */
    XcmV1Order: {
        _enum: {
            Noop: string;
            DepositAsset: {
                assets: string;
                maxAssets: string;
                beneficiary: string;
            };
            DepositReserveAsset: {
                assets: string;
                maxAssets: string;
                dest: string;
                effects: string;
            };
            ExchangeAsset: {
                give: string;
                receive: string;
            };
            InitiateReserveWithdraw: {
                assets: string;
                reserve: string;
                effects: string;
            };
            InitiateTeleport: {
                assets: string;
                dest: string;
                effects: string;
            };
            QueryHolding: {
                queryId: string;
                dest: string;
                assets: string;
            };
            BuyExecution: {
                fees: string;
                weight: string;
                debt: string;
                haltOnError: string;
                instructions: string;
            };
        };
    };
    /**
     * Lookup279: xcm::v1::Response
     */
    XcmV1Response: {
        _enum: {
            Assets: string;
            Version: string;
        };
    };
    /**
     * Lookup293: pallet_assets::pallet::Call<T, I>
     */
    PalletAssetsCall: {
        _enum: {
            create: {
                id: string;
                admin: string;
                minBalance: string;
            };
            force_create: {
                id: string;
                owner: string;
                isSufficient: string;
                minBalance: string;
            };
            destroy: {
                id: string;
                witness: string;
            };
            mint: {
                id: string;
                beneficiary: string;
                amount: string;
            };
            burn: {
                id: string;
                who: string;
                amount: string;
            };
            transfer: {
                id: string;
                target: string;
                amount: string;
            };
            transfer_keep_alive: {
                id: string;
                target: string;
                amount: string;
            };
            force_transfer: {
                id: string;
                source: string;
                dest: string;
                amount: string;
            };
            freeze: {
                id: string;
                who: string;
            };
            thaw: {
                id: string;
                who: string;
            };
            freeze_asset: {
                id: string;
            };
            thaw_asset: {
                id: string;
            };
            transfer_ownership: {
                id: string;
                owner: string;
            };
            set_team: {
                id: string;
                issuer: string;
                admin: string;
                freezer: string;
            };
            set_metadata: {
                id: string;
                name: string;
                symbol: string;
                decimals: string;
            };
            clear_metadata: {
                id: string;
            };
            force_set_metadata: {
                id: string;
                name: string;
                symbol: string;
                decimals: string;
                isFrozen: string;
            };
            force_clear_metadata: {
                id: string;
            };
            force_asset_status: {
                id: string;
                owner: string;
                issuer: string;
                admin: string;
                freezer: string;
                minBalance: string;
                isSufficient: string;
                isFrozen: string;
            };
            approve_transfer: {
                id: string;
                delegate: string;
                amount: string;
            };
            cancel_approval: {
                id: string;
                delegate: string;
            };
            force_cancel_approval: {
                id: string;
                owner: string;
                delegate: string;
            };
            transfer_approved: {
                id: string;
                owner: string;
                destination: string;
                amount: string;
            };
            touch: {
                id: string;
            };
            refund: {
                id: string;
                allowBurn: string;
            };
        };
    };
    /**
     * Lookup294: pallet_assets::types::DestroyWitness
     */
    PalletAssetsDestroyWitness: {
        accounts: string;
        sufficients: string;
        approvals: string;
    };
    /**
     * Lookup295: orml_xtokens::module::Call<T>
     */
    OrmlXtokensModuleCall: {
        _enum: {
            transfer: {
                currencyId: string;
                amount: string;
                dest: string;
                destWeightLimit: string;
            };
            transfer_multiasset: {
                asset: string;
                dest: string;
                destWeightLimit: string;
            };
            transfer_with_fee: {
                currencyId: string;
                amount: string;
                fee: string;
                dest: string;
                destWeightLimit: string;
            };
            transfer_multiasset_with_fee: {
                asset: string;
                fee: string;
                dest: string;
                destWeightLimit: string;
            };
            transfer_multicurrencies: {
                currencies: string;
                feeItem: string;
                dest: string;
                destWeightLimit: string;
            };
            transfer_multiassets: {
                assets: string;
                feeItem: string;
                dest: string;
                destWeightLimit: string;
            };
        };
    };
    /**
     * Lookup296: moonbase_runtime::xcm_config::CurrencyId
     */
    MoonbaseRuntimeXcmConfigCurrencyId: {
        _enum: {
            SelfReserve: string;
            ForeignAsset: string;
            LocalAssetReserve: string;
        };
    };
    /**
     * Lookup297: xcm::VersionedMultiAsset
     */
    XcmVersionedMultiAsset: {
        _enum: {
            V0: string;
            V1: string;
        };
    };
    /**
     * Lookup300: pallet_asset_manager::pallet::Call<T>
     */
    PalletAssetManagerCall: {
        _enum: {
            register_foreign_asset: {
                asset: string;
                metadata: string;
                minAmount: string;
                isSufficient: string;
            };
            set_asset_units_per_second: {
                assetType: string;
                unitsPerSecond: string;
                numAssetsWeightHint: string;
            };
            change_existing_asset_type: {
                assetId: string;
                newAssetType: string;
                numAssetsWeightHint: string;
            };
            remove_supported_asset: {
                assetType: string;
                numAssetsWeightHint: string;
            };
            remove_existing_asset_type: {
                assetId: string;
                numAssetsWeightHint: string;
            };
            register_local_asset: {
                creator: string;
                owner: string;
                isSufficient: string;
                minBalance: string;
            };
            destroy_foreign_asset: {
                assetId: string;
                destroyAssetWitness: string;
                numAssetsWeightHint: string;
            };
            destroy_local_asset: {
                assetId: string;
                destroyAssetWitness: string;
            };
        };
    };
    /**
     * Lookup301: pallet_migrations::pallet::Call<T>
     */
    PalletMigrationsCall: {
        _enum: {
            migrate_democracy_preimage: {
                proposalHash: string;
                proposalLenUpperBound: string;
            };
        };
    };
    /**
     * Lookup302: pallet_xcm_transactor::pallet::Call<T>
     */
    PalletXcmTransactorCall: {
        _enum: {
            register: {
                who: string;
                index: string;
            };
            deregister: {
                index: string;
            };
            transact_through_derivative: {
                dest: string;
                index: string;
                fee: string;
                innerCall: string;
                weightInfo: string;
            };
            transact_through_sovereign: {
                dest: string;
                feePayer: string;
                fee: string;
                call: string;
                originKind: string;
                weightInfo: string;
            };
            set_transact_info: {
                location: string;
                transactExtraWeight: string;
                maxWeight: string;
                transactExtraWeightSigned: string;
            };
            remove_transact_info: {
                location: string;
            };
            transact_through_signed: {
                dest: string;
                fee: string;
                call: string;
                weightInfo: string;
            };
            set_fee_per_second: {
                assetLocation: string;
                feePerSecond: string;
            };
            remove_fee_per_second: {
                assetLocation: string;
            };
            hrmp_manage: {
                action: string;
                fee: string;
                weightInfo: string;
            };
        };
    };
    /**
     * Lookup303: moonbase_runtime::xcm_config::Transactors
     */
    MoonbaseRuntimeXcmConfigTransactors: {
        _enum: string[];
    };
    /**
     * Lookup304:
     * pallet_xcm_transactor::pallet::CurrencyPayment<moonbase_runtime::xcm_config::CurrencyId>
     */
    PalletXcmTransactorCurrencyPayment: {
        currency: string;
        feeAmount: string;
    };
    /**
     * Lookup305:
     * pallet_xcm_transactor::pallet::Currency<moonbase_runtime::xcm_config::CurrencyId>
     */
    PalletXcmTransactorCurrency: {
        _enum: {
            AsCurrencyId: string;
            AsMultiLocation: string;
        };
    };
    /**
     * Lookup307: pallet_xcm_transactor::pallet::TransactWeights
     */
    PalletXcmTransactorTransactWeights: {
        transactRequiredWeightAtMost: string;
        overallWeight: string;
    };
    /**
     * Lookup309: pallet_moonbeam_orbiters::pallet::Call<T>
     */
    PalletMoonbeamOrbitersCall: {
        _enum: {
            collator_add_orbiter: {
                orbiter: string;
            };
            collator_remove_orbiter: {
                orbiter: string;
            };
            orbiter_leave_collator_pool: {
                collator: string;
            };
            orbiter_register: string;
            orbiter_unregister: {
                collatorsPoolCount: string;
            };
            add_collator: {
                collator: string;
            };
            remove_collator: {
                collator: string;
            };
        };
    };
    /**
     * Lookup310: pallet_ethereum_xcm::pallet::Call<T>
     */
    PalletEthereumXcmCall: {
        _enum: {
            transact: {
                xcmTransaction: string;
            };
            transact_through_proxy: {
                transactAs: string;
                xcmTransaction: string;
            };
            suspend_ethereum_xcm_execution: string;
            resume_ethereum_xcm_execution: string;
        };
    };
    /**
     * Lookup311: xcm_primitives::ethereum_xcm::EthereumXcmTransaction
     */
    XcmPrimitivesEthereumXcmEthereumXcmTransaction: {
        _enum: {
            V1: string;
            V2: string;
        };
    };
    /**
     * Lookup312: xcm_primitives::ethereum_xcm::EthereumXcmTransactionV1
     */
    XcmPrimitivesEthereumXcmEthereumXcmTransactionV1: {
        gasLimit: string;
        feePayment: string;
        action: string;
        value: string;
        input: string;
        accessList: string;
    };
    /**
     * Lookup313: xcm_primitives::ethereum_xcm::EthereumXcmFee
     */
    XcmPrimitivesEthereumXcmEthereumXcmFee: {
        _enum: {
            Manual: string;
            Auto: string;
        };
    };
    /**
     * Lookup314: xcm_primitives::ethereum_xcm::ManualEthereumXcmFee
     */
    XcmPrimitivesEthereumXcmManualEthereumXcmFee: {
        gasPrice: string;
        maxFeePerGas: string;
    };
    /**
     * Lookup317: xcm_primitives::ethereum_xcm::EthereumXcmTransactionV2
     */
    XcmPrimitivesEthereumXcmEthereumXcmTransactionV2: {
        gasLimit: string;
        action: string;
        value: string;
        input: string;
        accessList: string;
    };
    /**
     * Lookup318: pallet_randomness::pallet::Call<T>
     */
    PalletRandomnessCall: {
        _enum: string[];
    };
    /**
     * Lookup320: pallet_conviction_voting::pallet::Call<T, I>
     */
    PalletConvictionVotingCall: {
        _enum: {
            vote: {
                pollIndex: string;
                vote: string;
            };
            delegate: {
                class: string;
                to: string;
                conviction: string;
                balance: string;
            };
            undelegate: {
                class: string;
            };
            unlock: {
                class: string;
                target: string;
            };
            remove_vote: {
                class: string;
                index: string;
            };
            remove_other_vote: {
                target: string;
                class: string;
                index: string;
            };
        };
    };
    /**
     * Lookup321: pallet_conviction_voting::vote::AccountVote<Balance>
     */
    PalletConvictionVotingVoteAccountVote: {
        _enum: {
            Standard: {
                vote: string;
                balance: string;
            };
            Split: {
                aye: string;
                nay: string;
            };
        };
    };
    /**
     * Lookup323: pallet_conviction_voting::conviction::Conviction
     */
    PalletConvictionVotingConviction: {
        _enum: string[];
    };
    /**
     * Lookup325: pallet_referenda::pallet::Call<T, I>
     */
    PalletReferendaCall: {
        _enum: {
            submit: {
                proposalOrigin: string;
                proposal: string;
                enactmentMoment: string;
            };
            place_decision_deposit: {
                index: string;
            };
            refund_decision_deposit: {
                index: string;
            };
            cancel: {
                index: string;
            };
            kill: {
                index: string;
            };
            nudge_referendum: {
                index: string;
            };
            one_fewer_deciding: {
                track: string;
            };
        };
    };
    /**
     * Lookup326: frame_support::traits::schedule::DispatchTime<BlockNumber>
     */
    FrameSupportScheduleDispatchTime: {
        _enum: {
            At: string;
            After: string;
        };
    };
    /**
     * Lookup327: pallet_preimage::pallet::Call<T>
     */
    PalletPreimageCall: {
        _enum: {
            note_preimage: {
                bytes: string;
            };
            unnote_preimage: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
            request_preimage: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
            unrequest_preimage: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
        };
    };
    /**
     * Lookup328: pallet_whitelist::pallet::Call<T>
     */
    PalletWhitelistCall: {
        _enum: {
            whitelist_call: {
                callHash: string;
            };
            remove_whitelisted_call: {
                callHash: string;
            };
            dispatch_whitelisted_call: {
                callHash: string;
                callWeightWitness: string;
            };
            dispatch_whitelisted_call_with_preimage: {
                call: string;
            };
        };
    };
    /**
     * Lookup331: pallet_conviction_voting::types::Tally<Votes, Total>
     */
    PalletConvictionVotingTally: {
        ayes: string;
        nays: string;
        support: string;
    };
    /**
     * Lookup332: pallet_preimage::pallet::Event<T>
     */
    PalletPreimageEvent: {
        _enum: {
            Noted: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
            Requested: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
            Cleared: {
                _alias: {
                    hash_: string;
                };
                hash_: string;
            };
        };
    };
    /**
     * Lookup333: pallet_whitelist::pallet::Event<T>
     */
    PalletWhitelistEvent: {
        _enum: {
            CallWhitelisted: {
                callHash: string;
            };
            WhitelistedCallRemoved: {
                callHash: string;
            };
            WhitelistedCallDispatched: {
                callHash: string;
                result: string;
            };
        };
    };
    /**
     * Lookup335: frame_support::dispatch::PostDispatchInfo
     */
    FrameSupportDispatchPostDispatchInfo: {
        actualWeight: string;
        paysFee: string;
    };
    /**
     * Lookup337:
     * sp_runtime::DispatchErrorWithPostInfo<frame_support::dispatch::PostDispatchInfo>
     */
    SpRuntimeDispatchErrorWithPostInfo: {
        postInfo: string;
        error: string;
    };
    /**
     * Lookup339: frame_system::Phase
     */
    FrameSystemPhase: {
        _enum: {
            ApplyExtrinsic: string;
            Finalization: string;
            Initialization: string;
        };
    };
    /**
     * Lookup341: frame_system::LastRuntimeUpgradeInfo
     */
    FrameSystemLastRuntimeUpgradeInfo: {
        specVersion: string;
        specName: string;
    };
    /**
     * Lookup342: frame_system::limits::BlockWeights
     */
    FrameSystemLimitsBlockWeights: {
        baseBlock: string;
        maxBlock: string;
        perClass: string;
    };
    /**
     * Lookup343:
     * frame_support::dispatch::PerDispatchClass<frame_system::limits::WeightsPerClass>
     */
    FrameSupportDispatchPerDispatchClassWeightsPerClass: {
        normal: string;
        operational: string;
        mandatory: string;
    };
    /**
     * Lookup344: frame_system::limits::WeightsPerClass
     */
    FrameSystemLimitsWeightsPerClass: {
        baseExtrinsic: string;
        maxExtrinsic: string;
        maxTotal: string;
        reserved: string;
    };
    /**
     * Lookup345: frame_system::limits::BlockLength
     */
    FrameSystemLimitsBlockLength: {
        max: string;
    };
    /**
     * Lookup346: frame_support::dispatch::PerDispatchClass<T>
     */
    FrameSupportDispatchPerDispatchClassU32: {
        normal: string;
        operational: string;
        mandatory: string;
    };
    /**
     * Lookup347: sp_weights::RuntimeDbWeight
     */
    SpWeightsRuntimeDbWeight: {
        read: string;
        write: string;
    };
    /**
     * Lookup348: sp_version::RuntimeVersion
     */
    SpVersionRuntimeVersion: {
        specName: string;
        implName: string;
        authoringVersion: string;
        specVersion: string;
        implVersion: string;
        apis: string;
        transactionVersion: string;
        stateVersion: string;
    };
    /**
     * Lookup352: frame_system::pallet::Error<T>
     */
    FrameSystemError: {
        _enum: string[];
    };
    /**
     * Lookup353: pallet_utility::pallet::Error<T>
     */
    PalletUtilityError: {
        _enum: string[];
    };
    /**
     * Lookup355: pallet_balances::BalanceLock<Balance>
     */
    PalletBalancesBalanceLock: {
        id: string;
        amount: string;
        reasons: string;
    };
    /**
     * Lookup356: pallet_balances::Reasons
     */
    PalletBalancesReasons: {
        _enum: string[];
    };
    /**
     * Lookup359: pallet_balances::ReserveData<ReserveIdentifier, Balance>
     */
    PalletBalancesReserveData: {
        id: string;
        amount: string;
    };
    /**
     * Lookup361: pallet_balances::Releases
     */
    PalletBalancesReleases: {
        _enum: string[];
    };
    /**
     * Lookup362: pallet_balances::pallet::Error<T, I>
     */
    PalletBalancesError: {
        _enum: string[];
    };
    /**
     * Lookup363: pallet_sudo::pallet::Error<T>
     */
    PalletSudoError: {
        _enum: string[];
    };
    /**
     * Lookup366: polkadot_primitives::v2::UpgradeRestriction
     */
    PolkadotPrimitivesV2UpgradeRestriction: {
        _enum: string[];
    };
    /**
     * Lookup367:
     * cumulus_pallet_parachain_system::relay_state_snapshot::MessagingStateSnapshot
     */
    CumulusPalletParachainSystemRelayStateSnapshotMessagingStateSnapshot: {
        dmqMqcHead: string;
        relayDispatchQueueSize: string;
        ingressChannels: string;
        egressChannels: string;
    };
    /**
     * Lookup370: polkadot_primitives::v2::AbridgedHrmpChannel
     */
    PolkadotPrimitivesV2AbridgedHrmpChannel: {
        maxCapacity: string;
        maxTotalSize: string;
        maxMessageSize: string;
        msgCount: string;
        totalSize: string;
        mqcHead: string;
    };
    /**
     * Lookup371: polkadot_primitives::v2::AbridgedHostConfiguration
     */
    PolkadotPrimitivesV2AbridgedHostConfiguration: {
        maxCodeSize: string;
        maxHeadDataSize: string;
        maxUpwardQueueCount: string;
        maxUpwardQueueSize: string;
        maxUpwardMessageSize: string;
        maxUpwardMessageNumPerCandidate: string;
        hrmpMaxMessageNumPerCandidate: string;
        validationUpgradeCooldown: string;
        validationUpgradeDelay: string;
    };
    /**
     * Lookup377:
     * polkadot_core_primitives::OutboundHrmpMessage<polkadot_parachain::primitives::Id>
     */
    PolkadotCorePrimitivesOutboundHrmpMessage: {
        recipient: string;
        data: string;
    };
    /**
     * Lookup378: cumulus_pallet_parachain_system::pallet::Error<T>
     */
    CumulusPalletParachainSystemError: {
        _enum: string[];
    };
    /**
     * Lookup380: pallet_transaction_payment::Releases
     */
    PalletTransactionPaymentReleases: {
        _enum: string[];
    };
    /**
     * Lookup382: pallet_evm::pallet::Error<T>
     */
    PalletEvmError: {
        _enum: string[];
    };
    /**
     * Lookup385: fp_rpc::TransactionStatus
     */
    FpRpcTransactionStatus: {
        transactionHash: string;
        transactionIndex: string;
        from: string;
        to: string;
        contractAddress: string;
        logs: string;
        logsBloom: string;
    };
    /**
     * Lookup388: ethbloom::Bloom
     */
    EthbloomBloom: string;
    /**
     * Lookup390: ethereum::receipt::ReceiptV3
     */
    EthereumReceiptReceiptV3: {
        _enum: {
            Legacy: string;
            EIP2930: string;
            EIP1559: string;
        };
    };
    /**
     * Lookup391: ethereum::receipt::EIP658ReceiptData
     */
    EthereumReceiptEip658ReceiptData: {
        statusCode: string;
        usedGas: string;
        logsBloom: string;
        logs: string;
    };
    /**
     * Lookup392:
     * ethereum::block::Block[ethereum::transaction::TransactionV2](ethereum::transaction::TransactionV2)
     */
    EthereumBlock: {
        header: string;
        transactions: string;
        ommers: string;
    };
    /**
     * Lookup393: ethereum::header::Header
     */
    EthereumHeader: {
        parentHash: string;
        ommersHash: string;
        beneficiary: string;
        stateRoot: string;
        transactionsRoot: string;
        receiptsRoot: string;
        logsBloom: string;
        difficulty: string;
        number: string;
        gasLimit: string;
        gasUsed: string;
        timestamp: string;
        extraData: string;
        mixHash: string;
        nonce: string;
    };
    /**
     * Lookup394: ethereum_types::hash::H64
     */
    EthereumTypesHashH64: string;
    /**
     * Lookup399: pallet_ethereum::pallet::Error<T>
     */
    PalletEthereumError: {
        _enum: string[];
    };
    /**
     * Lookup400:
     * pallet_parachain_staking::types::ParachainBondConfig[account::AccountId20](account::AccountId20)
     */
    PalletParachainStakingParachainBondConfig: {
        account: string;
        percent: string;
    };
    /**
     * Lookup401: pallet_parachain_staking::types::RoundInfo<BlockNumber>
     */
    PalletParachainStakingRoundInfo: {
        current: string;
        first: string;
        length: string;
    };
    /**
     * Lookup402: pallet_parachain_staking::types::Delegator<account::AccountId20, Balance>
     */
    PalletParachainStakingDelegator: {
        id: string;
        delegations: string;
        total: string;
        lessTotal: string;
        status: string;
    };
    /**
     * Lookup403:
     * pallet_parachain_staking::set::OrderedSet<pallet_parachain_staking::types::Bond<account::AccountId20,
     * Balance>>
     */
    PalletParachainStakingSetOrderedSet: string;
    /**
     * Lookup404: pallet_parachain_staking::types::Bond<account::AccountId20, Balance>
     */
    PalletParachainStakingBond: {
        owner: string;
        amount: string;
    };
    /**
     * Lookup406: pallet_parachain_staking::types::DelegatorStatus
     */
    PalletParachainStakingDelegatorStatus: {
        _enum: {
            Active: string;
            Leaving: string;
        };
    };
    /**
     * Lookup407: pallet_parachain_staking::types::CandidateMetadata<Balance>
     */
    PalletParachainStakingCandidateMetadata: {
        bond: string;
        delegationCount: string;
        totalCounted: string;
        lowestTopDelegationAmount: string;
        highestBottomDelegationAmount: string;
        lowestBottomDelegationAmount: string;
        topCapacity: string;
        bottomCapacity: string;
        request: string;
        status: string;
    };
    /**
     * Lookup408: pallet_parachain_staking::types::CapacityStatus
     */
    PalletParachainStakingCapacityStatus: {
        _enum: string[];
    };
    /**
     * Lookup410: pallet_parachain_staking::types::CandidateBondLessRequest<Balance>
     */
    PalletParachainStakingCandidateBondLessRequest: {
        amount: string;
        whenExecutable: string;
    };
    /**
     * Lookup411: pallet_parachain_staking::types::CollatorStatus
     */
    PalletParachainStakingCollatorStatus: {
        _enum: {
            Active: string;
            Idle: string;
            Leaving: string;
        };
    };
    /**
     * Lookup413:
     * pallet_parachain_staking::delegation_requests::ScheduledRequest<account::AccountId20,
     * Balance>
     */
    PalletParachainStakingDelegationRequestsScheduledRequest: {
        delegator: string;
        whenExecutable: string;
        action: string;
    };
    /**
     * Lookup415:
     * pallet_parachain_staking::auto_compound::AutoCompoundConfig[account::AccountId20](account::AccountId20)
     */
    PalletParachainStakingAutoCompoundAutoCompoundConfig: {
        delegator: string;
        value: string;
    };
    /**
     * Lookup416:
     * pallet_parachain_staking::types::Delegations<account::AccountId20, Balance>
     */
    PalletParachainStakingDelegations: {
        delegations: string;
        total: string;
    };
    /**
     * Lookup418:
     * pallet_parachain_staking::types::CollatorSnapshot<account::AccountId20, Balance>
     */
    PalletParachainStakingCollatorSnapshot: {
        bond: string;
        delegations: string;
        total: string;
    };
    /**
     * Lookup420:
     * pallet_parachain_staking::types::BondWithAutoCompound<account::AccountId20, Balance>
     */
    PalletParachainStakingBondWithAutoCompound: {
        owner: string;
        amount: string;
        autoCompound: string;
    };
    /**
     * Lookup421: pallet_parachain_staking::types::DelayedPayout<Balance>
     */
    PalletParachainStakingDelayedPayout: {
        roundIssuance: string;
        totalStakingReward: string;
        collatorCommission: string;
    };
    /**
     * Lookup422: pallet_parachain_staking::inflation::InflationInfo<Balance>
     */
    PalletParachainStakingInflationInflationInfo: {
        expect: {
            min: string;
            ideal: string;
            max: string;
        };
        annual: {
            min: string;
            ideal: string;
            max: string;
        };
        round: {
            min: string;
            ideal: string;
            max: string;
        };
    };
    /**
     * Lookup423: pallet_parachain_staking::pallet::Error<T>
     */
    PalletParachainStakingError: {
        _enum: string[];
    };
    /**
     * Lookup426: pallet_scheduler::Scheduled<Name,
     * frame_support::traits::preimages::Bounded<moonbase_runtime::RuntimeCall>,
     * BlockNumber, moonbase_runtime::OriginCaller, account::AccountId20>
     */
    PalletSchedulerScheduled: {
        maybeId: string;
        priority: string;
        call: string;
        maybePeriodic: string;
        origin: string;
    };
    /**
     * Lookup428: pallet_scheduler::pallet::Error<T>
     */
    PalletSchedulerError: {
        _enum: string[];
    };
    /**
     * Lookup434: pallet_democracy::types::ReferendumInfo<BlockNumber,
     * frame_support::traits::preimages::Bounded<moonbase_runtime::RuntimeCall>, Balance>
     */
    PalletDemocracyReferendumInfo: {
        _enum: {
            Ongoing: string;
            Finished: {
                approved: string;
                end: string;
            };
        };
    };
    /**
     * Lookup435: pallet_democracy::types::ReferendumStatus<BlockNumber,
     * frame_support::traits::preimages::Bounded<moonbase_runtime::RuntimeCall>, Balance>
     */
    PalletDemocracyReferendumStatus: {
        end: string;
        proposal: string;
        threshold: string;
        delay: string;
        tally: string;
    };
    /**
     * Lookup436: pallet_democracy::types::Tally<Balance>
     */
    PalletDemocracyTally: {
        ayes: string;
        nays: string;
        turnout: string;
    };
    /**
     * Lookup437: pallet_democracy::vote::Voting<Balance, account::AccountId20,
     * BlockNumber, MaxVotes>
     */
    PalletDemocracyVoteVoting: {
        _enum: {
            Direct: {
                votes: string;
                delegations: string;
                prior: string;
            };
            Delegating: {
                balance: string;
                target: string;
                conviction: string;
                delegations: string;
                prior: string;
            };
        };
    };
    /**
     * Lookup441: pallet_democracy::types::Delegations<Balance>
     */
    PalletDemocracyDelegations: {
        votes: string;
        capital: string;
    };
    /**
     * Lookup442: pallet_democracy::vote::PriorLock<BlockNumber, Balance>
     */
    PalletDemocracyVotePriorLock: string;
    /**
     * Lookup445: pallet_democracy::pallet::Error<T>
     */
    PalletDemocracyError: {
        _enum: string[];
    };
    /**
     * Lookup447: pallet_collective::Votes<account::AccountId20, BlockNumber>
     */
    PalletCollectiveVotes: {
        index: string;
        threshold: string;
        ayes: string;
        nays: string;
        end: string;
    };
    /**
     * Lookup448: pallet_collective::pallet::Error<T, I>
     */
    PalletCollectiveError: {
        _enum: string[];
    };
    /**
     * Lookup450: pallet_treasury::Proposal<account::AccountId20, Balance>
     */
    PalletTreasuryProposal: {
        proposer: string;
        value: string;
        beneficiary: string;
        bond: string;
    };
    /**
     * Lookup454: frame_support::PalletId
     */
    FrameSupportPalletId: string;
    /**
     * Lookup455: pallet_treasury::pallet::Error<T, I>
     */
    PalletTreasuryError: {
        _enum: string[];
    };
    /**
     * Lookup456: pallet_author_inherent::pallet::Error<T>
     */
    PalletAuthorInherentError: {
        _enum: string[];
    };
    /**
     * Lookup457: pallet_crowdloan_rewards::pallet::RewardInfo<T>
     */
    PalletCrowdloanRewardsRewardInfo: {
        totalReward: string;
        claimedReward: string;
        contributedRelayAddresses: string;
    };
    /**
     * Lookup459: pallet_crowdloan_rewards::pallet::Error<T>
     */
    PalletCrowdloanRewardsError: {
        _enum: string[];
    };
    /**
     * Lookup460: pallet_author_mapping::pallet::RegistrationInfo<T>
     */
    PalletAuthorMappingRegistrationInfo: {
        _alias: {
            keys_: string;
        };
        account: string;
        deposit: string;
        keys_: string;
    };
    /**
     * Lookup461: pallet_author_mapping::pallet::Error<T>
     */
    PalletAuthorMappingError: {
        _enum: string[];
    };
    /**
     * Lookup464: pallet_proxy::ProxyDefinition<account::AccountId20,
     * moonbase_runtime::ProxyType, BlockNumber>
     */
    PalletProxyProxyDefinition: {
        delegate: string;
        proxyType: string;
        delay: string;
    };
    /**
     * Lookup468: pallet_proxy::Announcement<account::AccountId20,
     * primitive_types::H256, BlockNumber>
     */
    PalletProxyAnnouncement: {
        real: string;
        callHash: string;
        height: string;
    };
    /**
     * Lookup470: pallet_proxy::pallet::Error<T>
     */
    PalletProxyError: {
        _enum: string[];
    };
    /**
     * Lookup471: pallet_maintenance_mode::pallet::Error<T>
     */
    PalletMaintenanceModeError: {
        _enum: string[];
    };
    /**
     * Lookup472: pallet_identity::types::Registration<Balance, MaxJudgements,
     * MaxAdditionalFields>
     */
    PalletIdentityRegistration: {
        judgements: string;
        deposit: string;
        info: string;
    };
    /**
     * Lookup479: pallet_identity::types::RegistrarInfo<Balance, account::AccountId20>
     */
    PalletIdentityRegistrarInfo: {
        account: string;
        fee: string;
        fields: string;
    };
    /**
     * Lookup481: pallet_identity::pallet::Error<T>
     */
    PalletIdentityError: {
        _enum: string[];
    };
    /**
     * Lookup483: cumulus_pallet_xcmp_queue::InboundChannelDetails
     */
    CumulusPalletXcmpQueueInboundChannelDetails: {
        sender: string;
        state: string;
        messageMetadata: string;
    };
    /**
     * Lookup484: cumulus_pallet_xcmp_queue::InboundState
     */
    CumulusPalletXcmpQueueInboundState: {
        _enum: string[];
    };
    /**
     * Lookup487: polkadot_parachain::primitives::XcmpMessageFormat
     */
    PolkadotParachainPrimitivesXcmpMessageFormat: {
        _enum: string[];
    };
    /**
     * Lookup490: cumulus_pallet_xcmp_queue::OutboundChannelDetails
     */
    CumulusPalletXcmpQueueOutboundChannelDetails: {
        recipient: string;
        state: string;
        signalsExist: string;
        firstIndex: string;
        lastIndex: string;
    };
    /**
     * Lookup491: cumulus_pallet_xcmp_queue::OutboundState
     */
    CumulusPalletXcmpQueueOutboundState: {
        _enum: string[];
    };
    /**
     * Lookup493: cumulus_pallet_xcmp_queue::QueueConfigData
     */
    CumulusPalletXcmpQueueQueueConfigData: {
        suspendThreshold: string;
        dropThreshold: string;
        resumeThreshold: string;
        thresholdWeight: string;
        weightRestrictDecay: string;
        xcmpMaxIndividualWeight: string;
    };
    /**
     * Lookup495: cumulus_pallet_xcmp_queue::pallet::Error<T>
     */
    CumulusPalletXcmpQueueError: {
        _enum: string[];
    };
    /**
     * Lookup496: cumulus_pallet_xcm::pallet::Error<T>
     */
    CumulusPalletXcmError: string;
    /**
     * Lookup497: cumulus_pallet_dmp_queue::ConfigData
     */
    CumulusPalletDmpQueueConfigData: {
        maxIndividual: string;
    };
    /**
     * Lookup498: cumulus_pallet_dmp_queue::PageIndexData
     */
    CumulusPalletDmpQueuePageIndexData: {
        beginUsed: string;
        endUsed: string;
        overweightCount: string;
    };
    /**
     * Lookup501: cumulus_pallet_dmp_queue::pallet::Error<T>
     */
    CumulusPalletDmpQueueError: {
        _enum: string[];
    };
    /**
     * Lookup502: pallet_xcm::pallet::QueryStatus<BlockNumber>
     */
    PalletXcmQueryStatus: {
        _enum: {
            Pending: {
                responder: string;
                maybeNotify: string;
                timeout: string;
            };
            VersionNotifier: {
                origin: string;
                isActive: string;
            };
            Ready: {
                response: string;
                at: string;
            };
        };
    };
    /**
     * Lookup505: xcm::VersionedResponse
     */
    XcmVersionedResponse: {
        _enum: {
            V0: string;
            V1: string;
            V2: string;
        };
    };
    /**
     * Lookup511: pallet_xcm::pallet::VersionMigrationStage
     */
    PalletXcmVersionMigrationStage: {
        _enum: {
            MigrateSupportedVersion: string;
            MigrateVersionNotifiers: string;
            NotifyCurrentTargets: string;
            MigrateAndNotifyOldTargets: string;
        };
    };
    /**
     * Lookup513: pallet_xcm::pallet::Error<T>
     */
    PalletXcmError: {
        _enum: string[];
    };
    /**
     * Lookup514: pallet_assets::types::AssetDetails<Balance,
     * account::AccountId20, DepositBalance>
     */
    PalletAssetsAssetDetails: {
        owner: string;
        issuer: string;
        admin: string;
        freezer: string;
        supply: string;
        deposit: string;
        minBalance: string;
        isSufficient: string;
        accounts: string;
        sufficients: string;
        approvals: string;
        isFrozen: string;
    };
    /**
     * Lookup516: pallet_assets::types::AssetAccount<Balance, DepositBalance, Extra>
     */
    PalletAssetsAssetAccount: {
        balance: string;
        isFrozen: string;
        reason: string;
        extra: string;
    };
    /**
     * Lookup517: pallet_assets::types::ExistenceReason<Balance>
     */
    PalletAssetsExistenceReason: {
        _enum: {
            Consumer: string;
            Sufficient: string;
            DepositHeld: string;
            DepositRefunded: string;
        };
    };
    /**
     * Lookup519: pallet_assets::types::Approval<Balance, DepositBalance>
     */
    PalletAssetsApproval: {
        amount: string;
        deposit: string;
    };
    /**
     * Lookup520: pallet_assets::types::AssetMetadata<DepositBalance,
     * sp_core::bounded::bounded_vec::BoundedVec<T, S>>
     */
    PalletAssetsAssetMetadata: {
        deposit: string;
        name: string;
        symbol: string;
        decimals: string;
        isFrozen: string;
    };
    /**
     * Lookup522: pallet_assets::pallet::Error<T, I>
     */
    PalletAssetsError: {
        _enum: string[];
    };
    /**
     * Lookup523: orml_xtokens::module::Error<T>
     */
    OrmlXtokensModuleError: {
        _enum: string[];
    };
    /**
     * Lookup524: pallet_asset_manager::pallet::AssetInfo<T>
     */
    PalletAssetManagerAssetInfo: {
        creator: string;
        deposit: string;
    };
    /**
     * Lookup526: pallet_asset_manager::pallet::Error<T>
     */
    PalletAssetManagerError: {
        _enum: string[];
    };
    /**
     * Lookup527: pallet_migrations::pallet::Error<T>
     */
    PalletMigrationsError: {
        _enum: string[];
    };
    /**
     * Lookup528: pallet_xcm_transactor::pallet::Error<T>
     */
    PalletXcmTransactorError: {
        _enum: string[];
    };
    /**
     * Lookup530:
     * pallet_moonbeam_orbiters::types::CollatorPoolInfo[account::AccountId20](account::AccountId20)
     */
    PalletMoonbeamOrbitersCollatorPoolInfo: {
        orbiters: string;
        maybeCurrentOrbiter: string;
        nextOrbiter: string;
    };
    /**
     * Lookup532:
     * pallet_moonbeam_orbiters::types::CurrentOrbiter[account::AccountId20](account::AccountId20)
     */
    PalletMoonbeamOrbitersCurrentOrbiter: {
        accountId: string;
        removed: string;
    };
    /**
     * Lookup533: pallet_moonbeam_orbiters::pallet::Error<T>
     */
    PalletMoonbeamOrbitersError: {
        _enum: string[];
    };
    /**
     * Lookup534: pallet_ethereum_xcm::pallet::Error<T>
     */
    PalletEthereumXcmError: {
        _enum: string[];
    };
    /**
     * Lookup535: pallet_randomness::types::RequestState<T>
     */
    PalletRandomnessRequestState: {
        request: string;
        deposit: string;
    };
    /**
     * Lookup536: pallet_randomness::types::Request<Balance,
     * pallet_randomness::types::RequestInfo<T>>
     */
    PalletRandomnessRequest: {
        refundAddress: string;
        contractAddress: string;
        fee: string;
        gasLimit: string;
        numWords: string;
        salt: string;
        info: string;
    };
    /**
     * Lookup537: pallet_randomness::types::RequestInfo<T>
     */
    PalletRandomnessRequestInfo: {
        _enum: {
            BabeEpoch: string;
            Local: string;
        };
    };
    /**
     * Lookup538: pallet_randomness::types::RequestType<T>
     */
    PalletRandomnessRequestType: {
        _enum: {
            BabeEpoch: string;
            Local: string;
        };
    };
    /**
     * Lookup539: pallet_randomness::types::RandomnessResult<primitive_types::H256>
     */
    PalletRandomnessRandomnessResult: {
        randomness: string;
        requestCount: string;
    };
    /**
     * Lookup540: pallet_randomness::pallet::Error<T>
     */
    PalletRandomnessError: {
        _enum: string[];
    };
    /**
     * Lookup544: pallet_conviction_voting::vote::Voting<Balance,
     * account::AccountId20, BlockNumber, PollIndex, MaxVotes>
     */
    PalletConvictionVotingVoteVoting: {
        _enum: {
            Casting: string;
            Delegating: string;
        };
    };
    /**
     * Lookup545: pallet_conviction_voting::vote::Casting<Balance, BlockNumber,
     * PollIndex, MaxVotes>
     */
    PalletConvictionVotingVoteCasting: {
        votes: string;
        delegations: string;
        prior: string;
    };
    /**
     * Lookup549: pallet_conviction_voting::types::Delegations<Balance>
     */
    PalletConvictionVotingDelegations: {
        votes: string;
        capital: string;
    };
    /**
     * Lookup550: pallet_conviction_voting::vote::PriorLock<BlockNumber, Balance>
     */
    PalletConvictionVotingVotePriorLock: string;
    /**
     * Lookup551: pallet_conviction_voting::vote::Delegating<Balance,
     * account::AccountId20, BlockNumber>
     */
    PalletConvictionVotingVoteDelegating: {
        balance: string;
        target: string;
        conviction: string;
        delegations: string;
        prior: string;
    };
    /**
     * Lookup555: pallet_conviction_voting::pallet::Error<T, I>
     */
    PalletConvictionVotingError: {
        _enum: string[];
    };
    /**
     * Lookup556: pallet_referenda::types::ReferendumInfo<TrackId,
     * moonbase_runtime::OriginCaller, Moment,
     * frame_support::traits::preimages::Bounded<moonbase_runtime::RuntimeCall>,
     * Balance, pallet_conviction_voting::types::Tally<Votes, Total>,
     * account::AccountId20, ScheduleAddress>
     */
    PalletReferendaReferendumInfo: {
        _enum: {
            Ongoing: string;
            Approved: string;
            Rejected: string;
            Cancelled: string;
            TimedOut: string;
            Killed: string;
        };
    };
    /**
     * Lookup557: pallet_referenda::types::ReferendumStatus<TrackId,
     * moonbase_runtime::OriginCaller, Moment,
     * frame_support::traits::preimages::Bounded<moonbase_runtime::RuntimeCall>,
     * Balance, pallet_conviction_voting::types::Tally<Votes, Total>,
     * account::AccountId20, ScheduleAddress>
     */
    PalletReferendaReferendumStatus: {
        track: string;
        origin: string;
        proposal: string;
        enactment: string;
        submitted: string;
        submissionDeposit: string;
        decisionDeposit: string;
        deciding: string;
        tally: string;
        inQueue: string;
        alarm: string;
    };
    /**
     * Lookup558: pallet_referenda::types::Deposit<account::AccountId20, Balance>
     */
    PalletReferendaDeposit: {
        who: string;
        amount: string;
    };
    /**
     * Lookup561: pallet_referenda::types::DecidingStatus<BlockNumber>
     */
    PalletReferendaDecidingStatus: {
        since: string;
        confirming: string;
    };
    /**
     * Lookup569: pallet_referenda::types::TrackInfo<Balance, Moment>
     */
    PalletReferendaTrackInfo: {
        name: string;
        maxDeciding: string;
        decisionDeposit: string;
        preparePeriod: string;
        decisionPeriod: string;
        confirmPeriod: string;
        minEnactmentPeriod: string;
        minApproval: string;
        minSupport: string;
    };
    /**
     * Lookup570: pallet_referenda::types::Curve
     */
    PalletReferendaCurve: {
        _enum: {
            LinearDecreasing: {
                length: string;
                floor: string;
                ceil: string;
            };
            SteppedDecreasing: {
                begin: string;
                end: string;
                step: string;
                period: string;
            };
            Reciprocal: {
                factor: string;
                xOffset: string;
                yOffset: string;
            };
        };
    };
    /**
     * Lookup573: pallet_referenda::pallet::Error<T, I>
     */
    PalletReferendaError: {
        _enum: string[];
    };
    /**
     * Lookup574: pallet_preimage::RequestStatus<account::AccountId20, Balance>
     */
    PalletPreimageRequestStatus: {
        _enum: {
            Unrequested: {
                deposit: string;
                len: string;
            };
            Requested: {
                deposit: string;
                count: string;
                len: string;
            };
        };
    };
    /**
     * Lookup579: pallet_preimage::pallet::Error<T>
     */
    PalletPreimageError: {
        _enum: string[];
    };
    /**
     * Lookup580: pallet_whitelist::pallet::Error<T>
     */
    PalletWhitelistError: {
        _enum: string[];
    };
    /**
     * Lookup583: account::EthereumSignature
     */
    AccountEthereumSignature: string;
    /**
     * Lookup585: frame_system::extensions::check_spec_version::CheckSpecVersion<T>
     */
    FrameSystemExtensionsCheckSpecVersion: string;
    /**
     * Lookup586: frame_system::extensions::check_tx_version::CheckTxVersion<T>
     */
    FrameSystemExtensionsCheckTxVersion: string;
    /**
     * Lookup587: frame_system::extensions::check_genesis::CheckGenesis<T>
     */
    FrameSystemExtensionsCheckGenesis: string;
    /**
     * Lookup590: frame_system::extensions::check_nonce::CheckNonce<T>
     */
    FrameSystemExtensionsCheckNonce: string;
    /**
     * Lookup591: frame_system::extensions::check_weight::CheckWeight<T>
     */
    FrameSystemExtensionsCheckWeight: string;
    /**
     * Lookup592: pallet_transaction_payment::ChargeTransactionPayment<T>
     */
    PalletTransactionPaymentChargeTransactionPayment: string;
    /**
     * Lookup594: moonbase_runtime::Runtime
     */
    MoonbaseRuntimeRuntime: string;
};
export default _default;
